@@ -4,11 +4,9 @@
 * acp_board [French]
 *
 * @package language
-* @version 1.1.1
-* @author Maël Soucaze (Maël Soucaze) <maelsoucaze@phpbb.com> http://mael.soucaze.com/
-* @author Elglobo (Mickaël Salfati) <elglobo@phpbb.com> http://www.phpbb-services.com/
-* @copyright (c) 2005 phpBB Group, 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-license.php GNU Public License
+* @version $Id$
+* @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
+* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
 *
 */
 
@@ -41,8 +39,8 @@ if (empty($lang) || !is_array($lang))
 $lang = array_merge($lang, array(
 	'ACP_BOARD_SETTINGS_EXPLAIN'	=> 'Vous pouvez effectuer ici les opérations basiques de votre forum, comme lui attribuer un nom et une description, régler son fuseau horaire ou encore définir sa langue par défaut.',
 	'CUSTOM_DATEFORMAT'				=> 'Personnaliser…',
-	'DEFAULT_DATE_FORMAT'			=> 'Format de la date ',
-	'DEFAULT_DATE_FORMAT_EXPLAIN'	=> 'Le format de la date est similaire à celui de la fonction PHP <code>date</code>.',
+	'DEFAULT_DATE_FORMAT'			=> 'Format de date ',
+	'DEFAULT_DATE_FORMAT_EXPLAIN'	=> 'Le format de date est similaire à celui de la fonction PHP <code>date</code>.',
 	'DEFAULT_LANGUAGE'				=> 'Langue par défaut ',
 	'DEFAULT_STYLE'					=> 'Style par défaut ',
 	'DISABLE_BOARD'					=> 'Désactiver le forum ',
@@ -53,7 +51,7 @@ $lang = array_merge($lang, array(
 	'SITE_NAME'						=> 'Nom du forum ',
 	'SYSTEM_DST'					=> 'Activer l’heure d’été ',
 	'SYSTEM_TIMEZONE'				=> 'Fuseau horaire des invités ',
-	'SYSTEM_TIMEZONE_EXPLAIN'			=> 'Fuseau horaire utilisé afin d’afficher les heures aux utilisateurs qui ne sont pas connectés (comme les invités et les robots). Les utilisateurs connectés règlent eux-mêmes leur fuseau horaire durant leur inscription ou modifient ce réglage par l’intermédiaire du panneau de contrôle de l’utilisateur.',
+	'SYSTEM_TIMEZONE_EXPLAIN'			=> 'Le fuseau horaire utilisé afin d’afficher les heures aux utilisateurs qui ne sont pas connectés (comme les invités et les robots). Les utilisateurs connectés règlent eux-mêmes leur fuseau horaire durant leur inscription ou modifient ce réglage par l’intermédiaire du panneau de contrôle de l’utilisateur.',
 	'WARNINGS_EXPIRE'				=> 'Durée des avertissements ',
 	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Nombre de jours qui s’écoulera avant qu’un avertissement n’expire automatiquement. Réglez cette valeur sur 0 afin de ne pas limiter les avertissements.',
 ));
@@ -133,8 +131,8 @@ $lang = array_merge($lang, array(
 	'BOXES_LIMIT'				=> 'Nombre maximum de messages privés par boîte ',
 	'BOXES_LIMIT_EXPLAIN'		=> 'Si leur boîte est pleine, les utilisateurs ne pourront pas recevoir davantage de messages privés que la valeur qui est insérée ici. Réglez cette valeur sur 0 afin de ne pas limiter le nombre de messages privés par boîte.',
 	'BOXES_MAX'					=> 'Nombre maximum de dossiers de messages privés ',
-	'BOXES_MAX_EXPLAIN'			=> 'Par défaut, les utilisateurs peuvent créer un certain nombre de dossiers qui leur permettent de stocker des messages privés.',
-	'ENABLE_PM_ICONS'			=> 'Activer l’utilisation des icônes de sujets dans les messages privés ',
+	'BOXES_MAX_EXPLAIN'			=> 'Par défaut, les utilisateurs peuvent créer des dossiers qui permettent de stocker des messages privés.',
+	'ENABLE_PM_ICONS'			=> 'Activer l’utilisation des icônes de sujet dans les messages privés ',
 	'FULL_FOLDER_ACTION'		=> 'Action par défaut lorsque un dossier est plein ',
 	'FULL_FOLDER_ACTION_EXPLAIN'=> 'L’action par défaut à réaliser lorsque le dossier d’un utilisateur est plein dans le cas où l’action spécifiée par l’utilisateur n’est pas applicable. La seule exception s’applique au dossier des « Messages envoyés », où l’action par défaut est d’automatiquement supprimer les messages les plus anciens.',
 	'HOLD_NEW_MESSAGES'			=> 'Mettre en attente les nouveaux messages',
@@ -154,8 +152,8 @@ $lang = array_merge($lang, array(
 
 	'BUMP_INTERVAL'					=> 'Intervalle de remontée des sujets ',
 	'BUMP_INTERVAL_EXPLAIN'			=> 'Nombre de minutes, d’heures ou de jours entre le dernier message d’un sujet et la possibilité de remonter ce même sujet. Réglez cette valeur sur 0 afin de désactiver la possibilité de remonter des sujets.',
-	'CHAR_LIMIT'					=> 'Nombre maximum de caractère(s) par message et message privé ',
-	'CHAR_LIMIT_EXPLAIN'			=> 'Le nombre maximum de caractère(s) que les utilisateurs peuvent saisir dans un message et dans un message privé. Réglez cette valeur sur 0 afin de ne pas limiter le nombre de caractère.',
+	'CHAR_LIMIT'					=> 'Nombre maximum de caractères par message et message privé ',
+	'CHAR_LIMIT_EXPLAIN'			=> 'Le nombre maximum de caractères que les utilisateurs peuvent saisir dans un message et dans un message privé. Réglez cette valeur sur 0 afin de ne pas limiter le nombre de caractère.',
 	'DELETE_TIME'					=> 'Limite de la durée de suppression ',
 	'DELETE_TIME_EXPLAIN'			=> 'Limite la durée de suppression possible concernant les nouveaux messages. Réglez cette valeur sur 0 afin de désactiver ce comportement.',
 	'DISPLAY_LAST_EDITED'			=> 'Afficher l’information concernant la date de la dernière édition ',
@@ -166,25 +164,25 @@ $lang = array_merge($lang, array(
 	'FLOOD_INTERVAL_EXPLAIN'		=> 'Nombre de secondes qu’un utilisateur doit attendre avant d’avoir la possibilité de publier de nouveaux messages. Si vous souhaitez autoriser les utilisateurs à ignorer cet intervalle, vous devrez modifier leurs permissions.',
 	'HOT_THRESHOLD'					=> 'Seuil de popularité des sujets ',
 	'HOT_THRESHOLD_EXPLAIN'			=> 'Le nombre de messages par sujet à atteindre afin qu’un sujet soit considéré comme populaire. Réglez cette valeur sur 0 afin de désactiver cette fonctionnalité.',
-	'MAX_POLL_OPTIONS'				=> 'Nombre maximum d’option(s) par sondage ',
+	'MAX_POLL_OPTIONS'				=> 'Nombre maximum d’options par sondage ',
 	'MAX_POST_FONT_SIZE'			=> 'Taille maximale de la police de caractères dans les messages et messages privés ',
 	'MAX_POST_FONT_SIZE_EXPLAIN'	=> 'La taille maximale de la police de caractères autorisée dans un message et dans un message privé. Réglez cette valeur sur 0 afin de ne pas limiter la taille de la police de caractères.',
 	'MAX_POST_IMG_HEIGHT'			=> 'Hauteur maximale des images dans les messages et messages privés ',
 	'MAX_POST_IMG_HEIGHT_EXPLAIN'	=> 'La hauteur maximale des images ou des fichiers Flash dans les messages et dans les messages privés. Réglez cette valeur sur 0 afin de ne pas limiter la hauteur.',
 	'MAX_POST_IMG_WIDTH'			=> 'Largeur maximale des images dans les messages et messages privés ',
 	'MAX_POST_IMG_WIDTH_EXPLAIN'	=> 'La largeur maximale des images ou des fichiers Flash dans les messages et dans les messages privés. Réglez cette valeur sur 0 afin de ne limiter la largeur.',
-	'MAX_POST_URLS'					=> 'Nombre maximum de lien(s) par message et message privé ',
-	'MAX_POST_URLS_EXPLAIN'			=> 'Le nombre maximum de lien(s) que les utilisateurs peuvent insérer dans un message et dans un message privé. Réglez cette valeur sur 0 afin de ne pas limiter le nombre de lien.',
-	'MIN_CHAR_LIMIT'				=> 'Nombre minimum de caractère(s) par message et message privé ',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Le nombre minimum de caractère(s) que les utilisateurs doivent saisir afin d’être en mesure de publier un message ou un message privé.',
+	'MAX_POST_URLS'					=> 'Nombre maximum de liens par message et message privé ',
+	'MAX_POST_URLS_EXPLAIN'			=> 'Le nombre maximum de liens que les utilisateurs peuvent insérer dans un message et dans un message privé. Réglez cette valeur sur 0 afin de ne pas limiter le nombre de lien.',
+	'MIN_CHAR_LIMIT'				=> 'Nombre minimum de caractères par message et message privé ',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Le nombre minimum de caractères que les utilisateurs doivent saisir afin d’être en mesure de publier un message ou un message privé. La valeur minimale de ce réglage est de 1.',
 	'POSTING'						=> 'Publication',
-	'POSTS_PER_PAGE'				=> 'Nombre de message(s) par page ',
+	'POSTS_PER_PAGE'				=> 'Nombre de messages par page ',
 	'QUOTE_DEPTH_LIMIT'				=> 'Profondeur maximale d’imbrication de citations ',
 	'QUOTE_DEPTH_LIMIT_EXPLAIN'		=> 'La profondeur maximale d’imbrication de citations dans un message et dans un message privé. Réglez cette valeur sur 0 afin de ne pas limiter la profondeur.',
-	'SMILIES_LIMIT'					=> 'Nombre maximum d’émoticône(s) par message et message privé ',
-	'SMILIES_LIMIT_EXPLAIN'			=> 'Le nombre maximum d’émoticône(s) que les utilisateurs peuvent insérer dans un message et dans un message privé. Réglez cette valeur sur 0 afin de ne pas limiter le nombre d’émoticône.',
-	'SMILIES_PER_PAGE'				=> 'Nombre d’émoticône(s) par page ',
-	'TOPICS_PER_PAGE'				=> 'Nombre de sujet(s) par page ',
+	'SMILIES_LIMIT'					=> 'Nombre maximum d’émoticônes par message et message privé ',
+	'SMILIES_LIMIT_EXPLAIN'			=> 'Le nombre maximum d’émoticônes que les utilisateurs peuvent insérer dans un message et dans un message privé. Réglez cette valeur sur 0 afin de ne pas limiter le nombre d’émoticône.',
+	'SMILIES_PER_PAGE'				=> 'Nombre d’émoticônes par page ',
+	'TOPICS_PER_PAGE'				=> 'Nombre de sujets par page ',
 ));
 
 // Signature Settings
@@ -198,11 +196,11 @@ $lang = array_merge($lang, array(
 	'MAX_SIG_IMG_WIDTH'				=> 'Largeur maximale des images dans la signature des utilisateurs ',
 	'MAX_SIG_IMG_WIDTH_EXPLAIN'		=> 'La largeur maximale des images et des fichiers Flash dans la signature des utilisateurs. Réglez cette valeur sur 0 afin de ne pas limiter la largeur.',
 	'MAX_SIG_LENGTH'				=> 'Longueur maximale de la signature des utilisateurs ',
-	'MAX_SIG_LENGTH_EXPLAIN'		=> 'Le nombre maximum de caractère(s) autorisé(s) dans la signature des utilisateurs.',
-	'MAX_SIG_SMILIES'				=> 'Nombre maximum d’émoticône(s) dans la signature des utilisateurs ',
-	'MAX_SIG_SMILIES_EXPLAIN'		=> 'Le nombre maximum d’émoticône(s) autorisée(s) dans la signature des utilisateurs. Réglez cette valeur sur 0 afin de ne pas limiter le nombre d’émoticône.',
-	'MAX_SIG_URLS'					=> 'Nombre maximum de lien(s) dans la signature des utilisateurs ',
-	'MAX_SIG_URLS_EXPLAIN'			=> 'Le nombre maximum de lien(s) autorisé(s) dans la signature des utilisateurs. Réglez cette valeur sur 0 afin de ne pas limiter le nombre de lien.',
+	'MAX_SIG_LENGTH_EXPLAIN'		=> 'Le nombre maximum de caractères autorisés dans la signature des utilisateurs.',
+	'MAX_SIG_SMILIES'				=> 'Nombre maximum d’émoticônes dans la signature des utilisateurs ',
+	'MAX_SIG_SMILIES_EXPLAIN'		=> 'Le nombre maximum d’émoticônes autorisées dans la signature des utilisateurs. Réglez cette valeur sur 0 afin de ne pas limiter le nombre d’émoticône.',
+	'MAX_SIG_URLS'					=> 'Nombre maximum de liens dans la signature des utilisateurs ',
+	'MAX_SIG_URLS_EXPLAIN'			=> 'Le nombre maximum de liens autorisés dans la signature des utilisateurs. Réglez cette valeur sur 0 afin de ne pas limiter le nombre de lien.',
 ));
 
 // Registration Settings
@@ -211,10 +209,10 @@ $lang = array_merge($lang, array(
 
 	'ACC_ACTIVATION'				=> 'Activation du compte ',
 	'ACC_ACTIVATION_EXPLAIN'		=> 'Détermine quels sont les utilisateurs qui bénéficieront d’un accès immédiat au forum ou si une confirmation leur sera demandée. Vous pouvez également désactiver entièrement les nouvelles inscriptions. « L’envoi de courriels par l’intermédiaire du forum » doit être activé afin d’être en mesure de pouvoir utiliser l’activation par un administrateur ou par l’utilisateur lui-même.',
-	'NEW_MEMBER_POST_LIMIT'			=> 'Limite de message(s) des nouveaux membres ',
-	'NEW_MEMBER_POST_LIMIT_EXPLAIN'	=> 'Les nouveaux membres sont membres du groupe des <em>Utilisateurs inscrits récemment</em> jusqu’à ce qu’ils atteignent ce nombre de message(s). Vous pouvez utiliser ce groupe afin d’empêcher ses membres à utiliser les fonctionnalités de la messagerie privée ou contrôler leur(s) message(s). <strong>Réglez cette valeur sur 0 afin de désactiver cette fonctionnalité.</strong>',
+	'NEW_MEMBER_POST_LIMIT'			=> 'Limite de messages des nouveaux membres ',
+	'NEW_MEMBER_POST_LIMIT_EXPLAIN'	=> 'Les nouveaux membres sont membres du groupe des <em>Utilisateurs inscrits récemment</em> jusqu’à ce qu’ils atteignent ce nombre de messages. Vous pouvez utiliser ce groupe afin d’empêcher ses membres à utiliser les fonctionnalités de la messagerie privée ou contrôler leurs messages. <strong>Réglez cette valeur sur 0 afin de désactiver cette fonctionnalité.</strong>',
 	'NEW_MEMBER_GROUP_DEFAULT'		=> 'Régler le groupe des utilisateurs inscrits récemment en tant que groupe par défaut ',
-	'NEW_MEMBER_GROUP_DEFAULT_EXPLAIN'	=> 'Si cette option est activée et qu’une nouvelle limite de message(s) des nouveaux membres est spécifiée, les nouveux utilisateurs inscrits récemment ne seront pas uniquement membres du groupe des <em>Utilisateurs inscrits récemment</em> mais ce groupe sera également leur groupe par défaut. Cela peut être utile si vous souhaitez attribuer un rang ou un avatar par défaut afin que tous les utilisateurs en bénéficient.',
+	'NEW_MEMBER_GROUP_DEFAULT_EXPLAIN'	=> 'Si cette option est activée et qu’une nouvelle limite de messages des nouveaux membres est spécifiée, les nouveux utilisateurs inscrits récemment ne seront pas uniquement membres du groupe des <em>Utilisateurs inscrits récemment</em> mais ce groupe sera également leur groupe par défaut. Cela peut être utile si vous souhaitez attribuer un rang ou un avatar par défaut afin que tous les utilisateurs en bénéficient.',
 
 	'ACC_ADMIN'					=> 'Par un administrateur',
 	'ACC_DISABLE'				=> 'Désactiver les inscriptions',
@@ -233,19 +231,19 @@ $lang = array_merge($lang, array(
 	'MIN_CHARS'					=> 'Min',
 	'NO_AUTH_PLUGIN'			=> 'Aucun plugin d’authentification n’a été trouvé.',
 	'PASSWORD_LENGTH'			=> 'Longueur du mot de passe ',
-	'PASSWORD_LENGTH_EXPLAIN'	=> 'Le nombre de caractère(s) minimum(s) et maximum(s) obligatoire(s) dans les mots de passe.',
-	'REG_LIMIT'					=> 'Nombre de tentative(s) d’inscription ',
-	'REG_LIMIT_EXPLAIN'			=> 'Le nombre de tentative(s) d’inscription possible(s) avant que la session d’un utilisateur n’expire et qu’une mesure de lutte contre les robots indésirables ne soit déclenchée.',
-	'USERNAME_ALPHA_ONLY'		=> 'Alphanumériques uniquement',
-	'USERNAME_ALPHA_SPACERS'	=> 'Alphanumériques et espaces',
+	'PASSWORD_LENGTH_EXPLAIN'	=> 'Le nombre de caractères minimums et maximums obligatoires dans les mots de passe.',
+	'REG_LIMIT'					=> 'Nombre de tentatives d’inscription ',
+	'REG_LIMIT_EXPLAIN'			=> 'Le nombre de tentatives d’inscription possibles avant que la session d’un utilisateur n’expire et qu’une mesure de lutte contre les robots indésirables ne soit déclenchée.',
+	'USERNAME_ALPHA_ONLY'		=> 'Lettres et chiffres uniquement',
+	'USERNAME_ALPHA_SPACERS'	=> 'Lettres, chiffres et séparateurs uniquement',
 	'USERNAME_ASCII'			=> 'ASCII (aucun caractère international)',
-	'USERNAME_LETTER_NUM'		=> 'Lettres et nombres',
-	'USERNAME_LETTER_NUM_SPACERS'	=> 'Lettres, nombres et espaces',
-	'USERNAME_CHARS'			=> 'Limite de caractère(s) des noms d’utilisateurs ',
+	'USERNAME_LETTER_NUM'		=> 'Lettres et chiffres',
+	'USERNAME_LETTER_NUM_SPACERS'	=> 'Lettres, chiffres et séparateurs',
+	'USERNAME_CHARS'			=> 'Limite de caractères des noms d’utilisateurs ',
 	'USERNAME_CHARS_ANY'		=> 'Caractères',
-	'USERNAME_CHARS_EXPLAIN'	=> 'Limite le type de caractères pouvant être utilisé dans les noms d’utilisateurs. Les espaces comprennent : espace, -, +, _, [ et ].',
+	'USERNAME_CHARS_EXPLAIN'	=> 'Limite le type de caractères pouvant être utilisé dans les noms d’utilisateurs. Les séparateurs comprennent les espaces, les tirets bas, les crochets et les symboles plus et moins.',
 	'USERNAME_LENGTH'			=> 'Longueur des noms d’utilisateurs ',
-	'USERNAME_LENGTH_EXPLAIN'	=> 'Le nombre de caractère(s) minimum(s) et maximum(s) obligatoire(s) dans les noms d’utilisateurs.',
+	'USERNAME_LENGTH_EXPLAIN'	=> 'Le nombre de caractères minimums et maximums obligatoires dans les noms d’utilisateurs.',
 ));
 
 // Feeds
@@ -260,8 +258,8 @@ $lang = array_merge($lang, array(
 
 	'ACP_FEED_ENABLE'					=> 'Activer les flux ',
 	'ACP_FEED_ENABLE_EXPLAIN'			=> 'Active ou désactive les flux ATOM dans la totalité du forum.<br />Si cette option est désactivée, tous les flux seront désactivés, sans prendre en compte les réglages spécifiés dans les options ci-dessous.',
-	'ACP_FEED_LIMIT'					=> 'Nombre d’objet(s) ',
-	'ACP_FEED_LIMIT_EXPLAIN'			=> 'Le nombre maximum d’objet(s) à afficher dans les flux.',
+	'ACP_FEED_LIMIT'					=> 'Nombre d’objets ',
+	'ACP_FEED_LIMIT_EXPLAIN'			=> 'Le nombre maximum d’objets à afficher dans les flux.',
 
 	'ACP_FEED_OVERALL'					=> 'Activer le flux des messages de l’ensemble du forum ',
 	'ACP_FEED_OVERALL_EXPLAIN'			=> 'Permet de consulter les nouveaux messages de l’ensemble du forum par l’intermédiaire d’un flux spécifique.',
@@ -316,7 +314,7 @@ $lang = array_merge($lang, array(
 	'CAPTCHA_PREVIEW_EXPLAIN'				=> 'Le plugin tel qu’il ressemblera lors de l’utilisation de la sélection actuelle.',
 
 	'CAPTCHA_SELECT'						=> 'Plugins installés ',
-	'CAPTCHA_SELECT_EXPLAIN'				=> 'La liste déroulante contient les plugins reconnus par le forum. Les entrées grisées correspondent aux plugins qui ne sont pas encore disponibles et qui peuvent avoir besoin d’être configurés avant de pouvoir être utilisés.',
+	'CAPTCHA_SELECT_EXPLAIN'				=> 'La liste déroulante contient les plugins reconnus par le forum. Les éléments grisés correspondent aux plugins qui ne sont pas encore disponibles et qui peuvent avoir besoin d’être configurés avant de pouvoir être utilisés.',
 	'CAPTCHA_CONFIGURE'						=> 'Configurer les plugins ',
 	'CAPTCHA_CONFIGURE_EXPLAIN'				=> 'Permet de configurer le plugin que vous sélectionnez.',
 	'CONFIGURE'								=> 'Configurer',
@@ -340,9 +338,9 @@ $lang = array_merge($lang, array(
 	'COOKIE_SECURE'				=> 'Cookie sécurisé ',
 	'COOKIE_SECURE_EXPLAIN'		=> 'Si votre serveur fonctionne avec SSL, vous devez activer cette option. Si vous activez cette option alors que votre serveur fonctionne avec SSL, il est probable que des erreurs surviennent lors des redirections.',
 	'ONLINE_LENGTH'				=> 'Durée d’apparition dans la liste des utilisateurs en ligne ',
-	'ONLINE_LENGTH_EXPLAIN'		=> 'Nombre de minute(s) avant que les utilisateurs inactifs n’apparaissent plus dans la liste des utilisateurs en ligne. Plus la valeur est élevée, plus le temps de génération de la liste sera long.',
+	'ONLINE_LENGTH_EXPLAIN'		=> 'Nombre de minutes avant que les utilisateurs inactifs n’apparaissent plus dans la liste des utilisateurs en ligne. Plus la valeur est élevée, plus le temps de génération de la liste sera long.',
 	'SESSION_LENGTH'			=> 'Durée de la session ',
-	'SESSION_LENGTH_EXPLAIN'	=> 'Les sessions expireront une fois que cette durée, en seconde(s), sera dépassée.',
+	'SESSION_LENGTH_EXPLAIN'	=> 'Les sessions expireront une fois que cette durée, en secondes, sera dépassée.',
 ));
 
 // Load Settings
@@ -417,7 +415,7 @@ $lang = array_merge($lang, array(
 	'ENABLE_GZIP_EXPLAIN'		=> 'Le contenu généré sera compressé avant d’être envoyé aux utilisateurs. Cela peut réduire le trafic du réseau mais augmentera en contrepartie l’utilisation du processeur de votre serveur et de vos utilisateurs. L’extension zlib de PHP doit être chargée afin que la compression soit effective.',
 	'FORCE_SERVER_VARS'			=> 'Forcer les réglages des liens du serveur ',
 	'FORCE_SERVER_VARS_EXPLAIN'	=> 'Si cette option est activée, les réglages du serveur que vous spécifierez ici seront utilisés à la place des valeurs déterminées automatiquement.',
-	'ICONS_PATH'				=> 'Chemin vers le répertoire de stockage des icônes de messages ',
+	'ICONS_PATH'				=> 'Chemin vers le répertoire de stockage des icônes de message ',
 	'ICONS_PATH_EXPLAIN'		=> 'Chemin depuis la racine de votre répertoire de phpBB, tel que <samp>images/icons</samp>.',
 	'PATH_SETTINGS'				=> 'Réglages du chemin',
 	'RANKS_PATH'				=> 'Chemin vers le répertoire de stockage des images de rangs ',
@@ -453,7 +451,7 @@ $lang = array_merge($lang, array(
 	'CLASS_B'						=> 'A.B',
 	'CLASS_C'						=> 'A.B.C',
 	'EMAIL_CHECK_MX'				=> 'Vérifier l’enregistrement MX des adresses de courrier électronique ',
-	'EMAIL_CHECK_MX_EXPLAIN'		=> 'Si cette option est activée, le domaine de l’adresse de courrier électronique spécifié lors de l’inscription et des modifications du profil sera vérifié afin de s’assurer qu’il possède un enregistrement MX valide.',
+	'EMAIL_CHECK_MX_EXPLAIN'		=> 'Si cette option est activée, le domaine de l’adresse de courrier électronique spécifié lors de l’inscription et des modifications du profil sera vérifié afin de s’assurer qu’il possède un enregistrement MX correct.',
 	'FORCE_PASS_CHANGE'				=> 'Forcer la modification du mot de passe ',
 	'FORCE_PASS_CHANGE_EXPLAIN'		=> 'Oblige les utilisateurs à modifier leur mot de passe après qu’un certain nombre de jours ne soit expiré. Réglez cette valeur sur 0 afin de désactiver ce comportement.',
 	'FORM_TIME_MAX'					=> 'Durée maximale de l’envoi des formulaires ',
@@ -476,7 +474,7 @@ $lang = array_merge($lang, array(
 	'NO_REF_VALIDATION'				=> 'Aucune',
 	'PASSWORD_TYPE'					=> 'Complexité du mot de passe ',
 	'PASSWORD_TYPE_EXPLAIN'			=> 'Détermine la complexité des mots de passe qui sont saisis ou modifiés. Chaque option inclut les options précédentes.',
-	'PASS_TYPE_ALPHA'				=> 'Doit contenir des lettres et des nombres',
+	'PASS_TYPE_ALPHA'				=> 'Doit contenir des lettres et des chiffres',
 	'PASS_TYPE_ANY'					=> 'Aucune obligation',
 	'PASS_TYPE_CASE'				=> 'Doit contenir des majuscules et des minuscules',
 	'PASS_TYPE_SYMBOL'				=> 'Doit contenir des symboles',
@@ -490,7 +488,7 @@ $lang = array_merge($lang, array(
 
 // Email Settings
 $lang = array_merge($lang, array(
-	'ACP_EMAIL_SETTINGS_EXPLAIN'	=> 'Ces informations sont utilisées lors de l’envoi de courriels à vos utilisateurs. Veuillez vous assurer que l’adresse de courrier électronique spécifiée est valide car les messages refusés ou échoués seront probablement retournés à cette adresse. Si votre hébergeur ne fournit aucun service d’envoi de courriels en PHP par défaut, vous pouvez envoyer directement des messages en utilisant le protocole SMTP. Cela demande l’adresse d’un serveur approprié (si besoin, demandez cela à votre hébergeur). Si le serveur exige une authentification (et seulement dans ce cas), saisissez le nom d’utilisateur, le mot de passe et la méthode d’authentification nécessaire.',
+	'ACP_EMAIL_SETTINGS_EXPLAIN'	=> 'Ces informations sont utilisées lors de l’envoi de courriels à vos utilisateurs. Veuillez vous assurer que l’adresse de courrier électronique spécifiée est correcte car les messages refusés ou échoués seront probablement retournés à cette adresse. Si votre hébergeur ne fournit aucun service d’envoi de courriels en PHP par défaut, vous pouvez envoyer directement des messages en utilisant le protocole SMTP. Cela demande l’adresse d’un serveur approprié (si besoin, demandez cela à votre hébergeur). Si le serveur exige une authentification (et seulement dans ce cas), saisissez le nom d’utilisateur, le mot de passe et la méthode d’authentification nécessaire.',
 
 	'ADMIN_EMAIL'					=> 'Adresse de courrier électronique de retour ',
 	'ADMIN_EMAIL_EXPLAIN'			=> 'Cette adresse sera utilisée comme l’adresse de retour dans tous les courriels. Cela correspond à l’adresse de courrier électronique du contact technique. Elle sera toujours utilisée comme l’adresse du chemin de retour et considérée comme celle de l’expéditeur dans les courriels.',
@@ -499,7 +497,7 @@ $lang = array_merge($lang, array(
 	'BOARD_HIDE_EMAILS'				=> 'Masquer les adresses de courrier électronique ',
 	'BOARD_HIDE_EMAILS_EXPLAIN'		=> 'Masque les adresses de courrier électronique afin qu’elles restent entièrement confidentielles.',
 	'CONTACT_EMAIL'					=> 'Adresse de courrier électronique de contact ',
-	'CONTACT_EMAIL_EXPLAIN'			=> 'Cette adresse sera utilisée lorsqu’un contact particulier est nécessaire, comme en cas de pourriel, d’erreur survenue, etc. Elle sera toujours utilisée comme l’adresse du chemin de l’envoi et considérée comme celle du destinataire dans les courriels.',
+	'CONTACT_EMAIL_EXPLAIN'			=> 'Cette adresse sera utilisée lorsqu’un contact particulier est nécessaire, comme en cas de message indésirable, d’erreur survenue, etc. Elle sera toujours utilisée comme l’adresse du chemin de l’envoi et considérée comme celle du destinataire dans les courriels.',
 	'EMAIL_FUNCTION_NAME'			=> 'Nom de la fonction de la messagerie électronique ',
 	'EMAIL_FUNCTION_NAME_EXPLAIN'	=> 'Correspond à la fonction de la messagerie électronique qui est utilisée afin d’envoyer des courriels par l’intermédiaire de PHP.',
 	'EMAIL_PACKAGE_SIZE'			=> 'Nombre de courriels envoyés en une seule fois ',
@@ -509,7 +507,7 @@ $lang = array_merge($lang, array(
 	'ENABLE_EMAIL'					=> 'Activer l’envoi de courriels par l’intermédiaire du forum ',
 	'ENABLE_EMAIL_EXPLAIN'			=> 'Si cette option est désactivée, aucun courriel ne pourra être envoyé à partir du forum. <em>Notez que ce réglage doit être activé afin que l’activation par l’utilisateur ou par l’administrateur soit fonctionnelle. Si vous utilisez actuellement l’activation « par l’utilisateur » ou « par l’administrateur » et que vous n’activez pas ce réglage, aucune activation ne sera nécessaire afin que les nouveaux comptes soient opérationnels.</em>',
 	'SMTP_AUTH_METHOD'				=> 'Méthode d’authentification de SMTP ',
-	'SMTP_AUTH_METHOD_EXPLAIN'		=> '’est utilisé que si un nom d’utilisateur et un mot de passe ont été renseignés. Veuillez demander cette information à votre hébergeur si vous n’êtes pas certain de la méthode à utiliser.',
+	'SMTP_AUTH_METHOD_EXPLAIN'		=> 'N’est utilisé que si un nom d’utilisateur et un mot de passe ont été renseignés. Veuillez demander cette information à votre hébergeur si vous n’êtes pas certain(e) de la méthode à utiliser.',
 	'SMTP_CRAM_MD5'					=> 'CRAM-MD5',
 	'SMTP_DIGEST_MD5'				=> 'DIGEST-MD5',
 	'SMTP_LOGIN'					=> 'LOGIN',
@@ -529,7 +527,7 @@ $lang = array_merge($lang, array(
 
 // Jabber settings
 $lang = array_merge($lang, array(
-	'ACP_JABBER_SETTINGS_EXPLAIN'	=> 'Vous pouvez activer et contrôler ici l’utilisation de Jabber afin d’envoyer des messages instantanés et des avertissements sur le forum. Jabber est un protocole libre et gratuit utilisable par tous. Certains serveurs Jabber incluent des passerelles qui vous permettent de contacter les utilisateurs des autres réseaux, mais tous les serveurs n’offrent pas cette possibilité. Veuillez vous assurer d’avoir saisi les informations du compte que vous avez inscrit, ces informations seront utilisées telles quelles.',
+	'ACP_JABBER_SETTINGS_EXPLAIN'	=> 'Vous pouvez activer et contrôler ici l’utilisation de Jabber afin d’envoyer des messages instantanés et des notifications sur le forum. Jabber est un protocole libre et gratuit utilisable par tous. Certains serveurs Jabber incluent des passerelles qui vous permettent de contacter les utilisateurs des autres réseaux, mais tous les serveurs n’offrent pas cette possibilité. Veuillez vous assurer d’avoir saisi les informations du compte que vous avez inscrit, ces informations seront utilisées telles quelles.',
 
 	'JAB_ENABLE'				=> 'Activer Jabber ',
 	'JAB_ENABLE_EXPLAIN'		=> 'Active l’utilisation de la messagerie et des notifications de Jabber.',
@@ -542,11 +540,11 @@ $lang = array_merge($lang, array(
 	'JAB_PORT_EXPLAIN'			=> 'Laissez cela vide sauf dans le cas où le port utilisé n’est pas le 5222 et que vous en avez connaissance.',
 	'JAB_SERVER'				=> 'Serveur Jabber ',
 	'JAB_SERVER_EXPLAIN'		=> 'Rendez-vous sur %sjabber.org%s afin de consulter la liste des serveurs.',
-	'JAB_SETTINGS_CHANGED'		=> 'Les réglages de Jabber ont été modifiés avec succès.',
+	'JAB_SETTINGS_CHANGED'		=> 'Les réglages de Jabber ont été modifiés.',
 	'JAB_USE_SSL'				=> 'Utiliser une connexion SSL ',
 	'JAB_USE_SSL_EXPLAIN'		=> 'Si cette option est activée, une connexion sécurisée essaiera d’être établie. Le port de Jabber sera modifié en 5223 si le port 5222 est spécifié.',
 	'JAB_USERNAME'				=> 'Nom d’utilisateur Jabber ou JID ',
-	'JAB_USERNAME_EXPLAIN'		=> 'Spécifiez un nom d’utilisateur inscrit ou un JID valide. La validité de ce nom d’utilisateur ne sera cependant pas vérifiée. Si vous ne spécifiez qu’un nom d’utilisateur, votre JID correspondra à votre nom d’utilisateur et au serveur spécifié ci-dessous. Dans le cas contraire, veuillez spécifier un JID valide, tel que utilisateur@jabber.org.',
+	'JAB_USERNAME_EXPLAIN'		=> 'Spécifiez un nom d’utilisateur inscrit ou un JID correct. La validité de ce nom d’utilisateur ne sera cependant pas vérifiée. Si vous ne spécifiez qu’un nom d’utilisateur, votre JID correspondra à votre nom d’utilisateur et au serveur spécifié ci-dessous. Dans le cas contraire, veuillez spécifier un JID correct, tel que utilisateur@jabber.org.',
 ));
 
 ?>
\ No newline at end of file
