@@ -4,11 +4,9 @@
 * acp_styles [French]
 *
 * @package language
-* @version 1.1.1
-* @author Maël Soucaze (Maël Soucaze) <maelsoucaze@phpbb.com> http://mael.soucaze.com/
-* @author Elglobo (Mickaël Salfati) <elglobo@phpbb.com> http://www.phpbb-services.com/
-* @copyright (c) 2005 phpBB Group, 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-license.php GNU Public License
+* @version $Id$
+* @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
+* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
 *
 */
 
@@ -64,10 +62,10 @@ $lang = array_merge($lang, array(
 	'CACHE_FILENAME'				=> 'Fichier template ',
 	'CACHE_FILESIZE'				=> 'Taille du fichier',
 	'CACHE_MODIFIED'				=> 'Modifié',
-	'CONFIRM_IMAGESET_REFRESH'		=> 'Êtes-vous sûr de vouloir rafraîchir toutes les données des ensembles d’images ? Cela écrasera toutes les modifications réalisées à partir de l’éditeur des ensembles d’images.',
-	'CONFIRM_TEMPLATE_CLEAR_CACHE'	=> 'Êtes-vous sûr de vouloir supprimer toutes les versions des fichiers template mis en cache ?',
-	'CONFIRM_TEMPLATE_REFRESH'		=> 'Êtes-vous sûr de vouloir rafraîchir toutes les données des templates stockés dans la base de données ? Cela écrasera toutes les modifications faites à partir de l’éditeur des templates stockés dans la base de données.',
-	'CONFIRM_THEME_REFRESH'			=> 'Êtes-vous sûr de vouloir rafraîchir les données des thèmes stockés dans la base de données ? Ceci écrasera toutes modifications faites à partir de l’éditeur des thèmes stockés dans la base de données.',
+	'CONFIRM_IMAGESET_REFRESH'		=> 'Êtes-vous sûr(e) de vouloir rafraîchir toutes les données des ensembles d’images ? Cela écrasera toutes les modifications réalisées à partir de l’éditeur des ensembles d’images.',
+	'CONFIRM_TEMPLATE_CLEAR_CACHE'	=> 'Êtes-vous sûr(e) de vouloir supprimer toutes les versions des fichiers template mis en cache ?',
+	'CONFIRM_TEMPLATE_REFRESH'		=> 'Êtes-vous sûr(e) de vouloir rafraîchir toutes les données des templates stockés dans la base de données ? Cela écrasera toutes les modifications faites à partir de l’éditeur des templates stockés dans la base de données.',
+	'CONFIRM_THEME_REFRESH'			=> 'Êtes-vous sûr(e) de vouloir rafraîchir les données des thèmes stockés dans la base de données ? Ceci écrasera toutes modifications faites à partir de l’éditeur des thèmes stockés dans la base de données.',
 	'COPYRIGHT'						=> 'Copyright ',
 	'CREATE_IMAGESET'				=> 'Créer un nouvel ensemble d’images',
 	'CREATE_STYLE'					=> 'Créer un nouveau style',
@@ -125,30 +123,30 @@ $lang = array_merge($lang, array(
 	'IMAGE_NAME'				=> 'Nom de l’image',
 	'IMAGE_PARAMETER'			=> 'Paramètre',
 	'IMAGE_VALUE'				=> 'Valeur',
-	'IMAGESET_ADDED'			=> 'L’ensemble d’images a été ajouté au système de fichiers avec succès.',
-	'IMAGESET_ADDED_DB'			=> 'L’ensemble d’images a été ajouté à la base de données avec succès.',
-	'IMAGESET_DELETED'			=> 'L’ensemble d’images a été supprimé avec succès.',
+	'IMAGESET_ADDED'			=> 'L’ensemble d’images a été ajouté au système de fichiers.',
+	'IMAGESET_ADDED_DB'			=> 'L’ensemble d’images a été ajouté à la base de données.',
+	'IMAGESET_DELETED'			=> 'L’ensemble d’images a été supprimé.',
 	'IMAGESET_DELETED_FS'		=> 'L’ensemble d’images a été supprimé de la base de données mais quelques fichiers peuvent subsister dans le système de fichiers.',
-	'IMAGESET_DETAILS_UPDATED'	=> 'Les informations concernant l’ensemble d’images ont été mises à jour avec succès.',
+	'IMAGESET_DETAILS_UPDATED'	=> 'Les informations concernant l’ensemble d’images ont été mises à jour.',
 	'IMAGESET_ERR_ARCHIVE'		=> 'Veuillez sélectionner une méthode de compression.',
 	'IMAGESET_ERR_COPY_LONG'	=> 'Le copyright ne doit pas dépasser 60 caractères.',
-	'IMAGESET_ERR_NAME_CHARS'	=> 'Le nom de l’ensemble d’images ne doit contenir que des caractères alphanumériques, -, +, _ et des espaces.',
+	'IMAGESET_ERR_NAME_CHARS'	=> 'Le nom de l’ensemble d’images ne doit contenir que des lettres, des chiffres, des tirets, des plus, des tirets bas et des espaces.',
 	'IMAGESET_ERR_NAME_EXIST'	=> 'Un ensemble d’images portant ce nom existe déjà.',
 	'IMAGESET_ERR_NAME_LONG'	=> 'Le nom de l’ensemble d’images ne doit pas dépasser 30 caractères.',
-	'IMAGESET_ERR_NOT_IMAGESET'	=> 'Le fichier compréssé que vous avez spécifié ne contient pas d’ensemble d’images valide.',
+	'IMAGESET_ERR_NOT_IMAGESET'	=> 'Le fichier compressé que vous avez spécifié ne contient pas d’ensemble d’images correct.',
 	'IMAGESET_ERR_STYLE_NAME'	=> 'Vous devez spécifier le nom de cet ensemble d’images.',
 	'IMAGESET_EXPORT'			=> 'Exporter un ensemble d’images',
-	'IMAGESET_EXPORT_EXPLAIN'	=> 'Vous pouvez exporter ici un ensemble d’images sous forme de fichier compréssé. Ce dernier contiendra toutes les données nécessaires afin d’installer l’ensemble d’images sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre dossier de stockage afin de le télécharger ultérieurement par FTP.',
-	'IMAGESET_EXPORTED'			=> 'L’ensemble d’images a été exporté et stocké dans %s avec succès.',
+	'IMAGESET_EXPORT_EXPLAIN'	=> 'Vous pouvez exporter ici un ensemble d’images sous forme de fichier compressé. Ce dernier contiendra toutes les données nécessaires afin d’installer l’ensemble d’images sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre dossier de stockage afin de le télécharger ultérieurement par FTP.',
+	'IMAGESET_EXPORTED'			=> 'L’ensemble d’images a été exporté et stocké dans %s.',
 	'IMAGESET_NAME'				=> 'Nom de l’ensemble d’images ',
-	'IMAGESET_REFRESHED'		=> 'L’ensemble d’images a été rafraîchi avec succès.',
-	'IMAGESET_UPDATED'			=> 'L’ensemble d’images a été mis à jour avec succès.',
+	'IMAGESET_REFRESHED'		=> 'L’ensemble d’images a été rafraîchi.',
+	'IMAGESET_UPDATED'			=> 'L’ensemble d’images a été mis à jour.',
 	'ITALIC'					=> 'Italique',
 
 	'IMG_CAT_BUTTONS'		=> 'Boutons traduits',
 	'IMG_CAT_CUSTOM'		=> 'Images personnalisées',
-	'IMG_CAT_FOLDERS'		=> 'Icônes de sujets',
-	'IMG_CAT_FORUMS'		=> 'Icônes de forums',
+	'IMG_CAT_FOLDERS'		=> 'Icônes de sujet',
+	'IMG_CAT_FORUMS'		=> 'Icônes de forum',
 	'IMG_CAT_ICONS'			=> 'Icônes générales',
 	'IMG_CAT_LOGOS'			=> 'Logos',
 	'IMG_CAT_POLLS'			=> 'Images de sondages',
@@ -277,7 +275,7 @@ $lang = array_merge($lang, array(
 	'INSTALL_IMAGESET'			=> 'Installer un ensemble d’images',
 	'INSTALL_IMAGESET_EXPLAIN'	=> 'Vous pouvez installer ici un ensemble d’images. Si vous le souhaitez, vous pouvez éditer certaines informations ou utiliser les valeurs par défaut lors de l’installation.',
 	'INSTALL_STYLE'				=> 'Installer un style',
-	'INSTALL_STYLE_EXPLAIN'		=> 'Vous pouvez installer ici un style et ses éléments. Si les éléments appropriés au style sont déjà installés, ils ne seront pas écrasés. Certains styles nécessitent que ces éléments soient déjà installés. Si vous en rencontrez un de ce genre, vous serez alors averti.',
+	'INSTALL_STYLE_EXPLAIN'		=> 'Vous pouvez installer ici un style et ses éléments. Si les éléments appropriés au style sont déjà installés, ils ne seront pas écrasés. Certains styles nécessitent que ces éléments soient déjà installés. Si vous en rencontrez un de ce genre, vous en serez alors informé(e).',
 	'INSTALL_TEMPLATE'			=> 'Installer un ensemble de templates',
 	'INSTALL_TEMPLATE_EXPLAIN'	=> 'Vous pouvez installer ici un ensemble de templates. Selon la configuration de votre serveur, vous pouvez rencontrer certaines options supplémentaires.',
 	'INSTALL_THEME'				=> 'Installer un thème',
@@ -345,88 +343,88 @@ $lang = array_merge($lang, array(
 	'STORE_FILESYSTEM'			=> 'Système de fichiers',
 	'STYLE_ACTIVATE'			=> 'Activer',
 	'STYLE_ACTIVE'				=> 'Activer ',
-	'STYLE_ADDED'				=> 'Le style a été ajouté avec succès.',
+	'STYLE_ADDED'				=> 'Le style a été ajouté.',
 	'STYLE_DEACTIVATE'			=> 'Désactiver',
 	'STYLE_DEFAULT'				=> 'En faire le style par défaut ',
-	'STYLE_DELETED'				=> 'Le style a été supprimé avec succès.',
-	'STYLE_DETAILS_UPDATED'		=> 'Le style a été édité avec succès.',
+	'STYLE_DELETED'				=> 'Le style a été supprimé.',
+	'STYLE_DETAILS_UPDATED'		=> 'Le style a été édité.',
 	'STYLE_ERR_ARCHIVE'			=> 'Veuillez sélectionner une méthode de compression.',
 	'STYLE_ERR_COPY_LONG'		=> 'Le copyright ne doit pas dépasser 60 caractères.',
 	'STYLE_ERR_MORE_ELEMENTS'	=> 'Vous devez sélectionner au moins un élément pour le style.',
-	'STYLE_ERR_NAME_CHARS'		=> 'Le nom du style ne doit contenir que des caractères alphanumériques, -, +, _ et des espaces.',
+	'STYLE_ERR_NAME_CHARS'		=> 'Le nom du style ne doit contenir que des lettres, des chiffres, des tirets, des plus, des tirets bas et des espaces.',
 	'STYLE_ERR_NAME_EXIST'		=> 'Un style portant ce nom existe déjà.',
 	'STYLE_ERR_NAME_LONG'		=> 'Le nom du style ne doit pas dépasser 30 caractères.',
 	'STYLE_ERR_NO_IDS'			=> 'Vous devez sélectionner un template, un thème et un ensemble d’images pour ce style.',
-	'STYLE_ERR_NOT_STYLE'		=> 'Le fichier importé ou transféré ne contient pas de fichier de style compressé valide.',
+	'STYLE_ERR_NOT_STYLE'		=> 'Le fichier importé ou transféré ne contient pas de fichier de style compressé correct.',
 	'STYLE_ERR_STYLE_NAME'		=> 'Vous devez spécifier le nom de ce style.',
 	'STYLE_EXPORT'				=> 'Exporter un style',
-	'STYLE_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter ici un style sous forme de fichier compréssé. Un style ne devra pas contenir tous les éléments, mais il doit en contenir au moins un. Par exemple, si vous créez un nouveau thème et un ensemble d’images pour un template fréquemment utilisé, vous pourriez simplement exporter le thème et l’ensemble d’images, en omettant le template. Vous pouvez soit télécharger le dossier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
-	'STYLE_EXPORTED'			=> 'Le style a été exporté et stocké dans %s avec succès.',
+	'STYLE_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter ici un style sous forme de fichier compressé. Un style ne devra pas contenir tous les éléments, mais il doit en contenir au moins un. Par exemple, si vous créez un nouveau thème et un ensemble d’images pour un template fréquemment utilisé, vous pourriez simplement exporter le thème et l’ensemble d’images, en omettant le template. Vous pouvez soit télécharger le dossier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
+	'STYLE_EXPORTED'			=> 'Le style a été exporté et stocké dans %s.',
 	'STYLE_IMAGESET'			=> 'Ensemble d’images ',
 	'STYLE_NAME'				=> 'Nom du style ',
 	'STYLE_TEMPLATE'			=> 'Template ',
 	'STYLE_THEME'				=> 'Thème ',
-	'STYLE_USED_BY'				=> 'Utilisé par (incluant les robots)',
+	'STYLE_USED_BY'				=> 'Utilisé par (en incluant les robots)',
 
-	'TEMPLATE_ADDED'			=> 'L’ensemble de templates a été ajouté au système de fichiers avec succès.',
-	'TEMPLATE_ADDED_DB'			=> 'L’ensemble de templates a été ajouté à la base de données avec succès.',
+	'TEMPLATE_ADDED'			=> 'L’ensemble de templates a été ajouté au système de fichiers.',
+	'TEMPLATE_ADDED_DB'			=> 'L’ensemble de templates a été ajouté à la base de données.',
 	'TEMPLATE_CACHE'			=> 'Cache du template',
 	'TEMPLATE_CACHE_EXPLAIN'	=> 'Par défaut, phpBB met en cache la version compilée de ses templates. Cela permet de diminuer la charge du serveur à chaque fois qu’une page est consultée et réduit le temps de chargement de la page. Vous pouvez consulter ici le statut en cache de chaque fichier et supprimer individuellement les fichiers ou le cache en entier.',
-	'TEMPLATE_CACHE_CLEARED'	=> 'Le cache du template a été vidé avec succès.',
+	'TEMPLATE_CACHE_CLEARED'	=> 'Le cache du template a été vidé.',
 	'TEMPLATE_CACHE_EMPTY'		=> 'Il n’y a aucun template mis en cache.',
-	'TEMPLATE_DELETED'			=> 'L’ensemble de templates a été supprimé avec succès.',
+	'TEMPLATE_DELETED'			=> 'L’ensemble de templates a été supprimé.',
 	'TEMPLATE_DELETE_DEPENDENT'   => 'L’ensemble de templates ne peut être supprimé car un ou plusieurs autres templates héritent de ce dernier :',
 	'TEMPLATE_DELETED_FS'		=> 'L’ensemble de templates a été supprimé de la base données mais certains fichiers ont été conservés dans le système de fichiers.',
-	'TEMPLATE_DETAILS_UPDATED'	=> 'Les informations concernant l’ensemble de templates ont été mises à jour avec succès.',
+	'TEMPLATE_DETAILS_UPDATED'	=> 'Les informations concernant l’ensemble de templates ont été mises à jour.',
 	'TEMPLATE_EDITOR'			=> 'Éditeur de templates en HTML brut',
 	'TEMPLATE_EDITOR_HEIGHT'	=> 'Taille de l’éditeur de templates ',
 	'TEMPLATE_ERR_ARCHIVE'		=> 'Veuillez sélectionner une méthode de compression.',
 	'TEMPLATE_ERR_CACHE_READ'	=> 'Le répertoire de cache utilisé afin de stocker les versions des fichiers de templates mis en cache ne peut pas être lu.',
 	'TEMPLATE_ERR_COPY_LONG'	=> 'Le copyright ne doit pas dépasser 60 caractères.',
-	'TEMPLATE_ERR_NAME_CHARS'	=> 'Le nom de l’ensemble de templates ne doit contenir que des caractères alphanumériques, -, +, _ et des espaces.',
+	'TEMPLATE_ERR_NAME_CHARS'	=> 'Le nom de l’ensemble de templates ne doit contenir que des lettres, des chiffres, des tirets, des plus, des tirets bas et des espaces.',
 	'TEMPLATE_ERR_NAME_EXIST'	=> 'Un ensemble de templates portant ce nom existe déjà.',
 	'TEMPLATE_ERR_NAME_LONG'	=> 'Le nom de l’ensemble de templates ne doit pas dépasser 30 caractères.',
-	'TEMPLATE_ERR_NOT_TEMPLATE'	=> 'Le fichier compressé que vous avez spécifié ne contient aucun ensemble de templates valide.',
+	'TEMPLATE_ERR_NOT_TEMPLATE'	=> 'Le fichier compressé que vous avez spécifié ne contient aucun ensemble de templates correct.',
 	'TEMPLATE_ERR_REQUIRED_OR_INCOMPLETE' => 'Le nouvel ensemble de templates requiert l’installation du template %s et ne doit pas hériter de ce dernier.',
 	'TEMPLATE_ERR_STYLE_NAME'	=> 'Vous devez spécifier le nom de cet ensemble de templates.',
 	'TEMPLATE_EXPORT'			=> 'Exporter un ensemble de templates',
-	'TEMPLATE_EXPORT_EXPLAIN'	=> 'Vous pouvez exporter ici un ensemble de templates sous forme de fichier compréssé. Le fichier compréssé ne devra pas contenir tous les fichiers nécessaires à l’installation de templates sur un autre forum. Vous pouvez soit télécharger le dossier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
-	'TEMPLATE_EXPORTED'			=> 'Les templates ont été exportés et stockés dans %s avec succès.',
+	'TEMPLATE_EXPORT_EXPLAIN'	=> 'Vous pouvez exporter ici un ensemble de templates sous forme de fichier compressé. Le fichier compressé ne devra pas contenir tous les fichiers nécessaires à l’installation de templates sur un autre forum. Vous pouvez soit télécharger le dossier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
+	'TEMPLATE_EXPORTED'			=> 'Les templates ont été exportés et stockés dans %s.',
 	'TEMPLATE_FILE'				=> 'Fichier template',
-	'TEMPLATE_FILE_UPDATED'		=> 'Le fichier template a été mis à jour avec succès.',
+	'TEMPLATE_FILE_UPDATED'		=> 'Le fichier template a été mis à jour.',
 	'TEMPLATE_INHERITS'         => 'Ces ensembles de templates héritent de %s et ne peuvent donc pas avoir de réglages de stockage différents à ceux du super template.',
 	'TEMPLATE_LOCATION'			=> 'Stocker les templates dans ',
 	'TEMPLATE_LOCATION_EXPLAIN'	=> 'Les images sont toujours stockées dans le système de fichiers.',
 	'TEMPLATE_NAME'				=> 'Nom du template ',
 	'TEMPLATE_FILE_NOT_WRITABLE'=> 'Impossible d’écrire sur le fichier template %s. Veuillez vérifier les permissions du répertoire et des fichiers.',
-	'TEMPLATE_REFRESHED'		=> 'Le template a été rafraîchi avec succès.',
+	'TEMPLATE_REFRESHED'		=> 'Le template a été rafraîchi.',
 
-	'THEME_ADDED'				=> 'Le thème a été ajouté au système de fichiers avec succès.',
-	'THEME_ADDED_DB'			=> 'Le thème a été ajouté à la base de données avec succès.',
-	'THEME_CLASS_ADDED'			=> 'La classe personnalisée a été ajoutée avec succès.',
-	'THEME_DELETED'				=> 'Le thème a été supprimé avec succès.',
+	'THEME_ADDED'				=> 'Le thème a été ajouté au système de fichiers.',
+	'THEME_ADDED_DB'			=> 'Le thème a été ajouté à la base de données.',
+	'THEME_CLASS_ADDED'			=> 'La classe personnalisée a été ajoutée.',
+	'THEME_DELETED'				=> 'Le thème a été supprimé.',
 	'THEME_DELETED_FS'			=> 'Le thème supprimé de la base de données mais quelques fichiers peuvent subsister dans le système de fichiers.',
-	'THEME_DETAILS_UPDATED'		=> 'Les informations du thème ont été mises à jour avec succès.',
+	'THEME_DETAILS_UPDATED'		=> 'Les informations du thème ont été mises à jour.',
 	'THEME_EDITOR'				=> 'Éditeur de thèmes',
 	'THEME_EDITOR_HEIGHT'		=> 'Taille de l’éditeur de thèmes ',
 	'THEME_ERR_ARCHIVE'			=> 'Veuillez sélectionner une méthode de compression.',
-	'THEME_ERR_CLASS_CHARS'		=> 'Seuls les caractère alphanumériques, ., :, -, _ et # sont valides dans les noms de classes.',
+	'THEME_ERR_CLASS_CHARS'		=> 'Seuls les lettres, les chiffres, les points, les deux-points, les tirets, les tirets bas et les croisillons sont tolérés dans les noms de classes.',
 	'THEME_ERR_COPY_LONG'		=> 'Le copyright ne doit pas dépasser 60 caractères.',
-	'THEME_ERR_NAME_CHARS'		=> 'Le nom du thème ne doit contenir que des caractères alphanumériques, -, +, _ et des espaces.',
+	'THEME_ERR_NAME_CHARS'		=> 'Le nom du thème ne doit contenir que des lettres, des chiffres, des tirets, des plus, des tirets bas et des espaces.',
 	'THEME_ERR_NAME_EXIST'		=> 'Un thème portant ce nom existe déjà.',
 	'THEME_ERR_NAME_LONG'		=> 'Le nom du thème ne doit pas dépasser 30 caractères.',
-	'THEME_ERR_NOT_THEME'		=> 'Le fichier compressé que vous avez spécifié ne contient pas de thème valide.',
+	'THEME_ERR_NOT_THEME'		=> 'Le fichier compressé que vous avez spécifié ne contient pas de thème correct.',
 	'THEME_ERR_REFRESH_FS'		=> 'Ce thème est stocké dans le système de fichiers. Il n’y a donc pas besoin de le rafraîchir.',
 	'THEME_ERR_STYLE_NAME'		=> 'Vous devez spécifier le nom de ce thème.',
 	'THEME_FILE'				=> 'Fichier thème',
 	'THEME_EXPORT'				=> 'Exporter un thème',
-	'THEME_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter ici un thème sous forme de fichier compréssé. Ce fichier compressé contiendra toutes les données nécessaires à l’installation du thème sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
-	'THEME_EXPORTED'			=> 'Le thème a été exporté et stocké dans %s avec succès.',
+	'THEME_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter ici un thème sous forme de fichier compressé. Ce fichier compressé contiendra toutes les données nécessaires à l’installation du thème sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
+	'THEME_EXPORTED'			=> 'Le thème a été exporté et stocké dans %s.',
 	'THEME_LOCATION'			=> 'Stocker la feuille de style dans ',
 	'THEME_LOCATION_EXPLAIN'	=> 'Les images sont toujours stockées dans le système de fichiers.',
 	'THEME_NAME'				=> 'Nom du thème ',
-	'THEME_REFRESHED'			=> 'Le thème a été rafraîchi avec succès.',
-	'THEME_UPDATED'				=> 'Le thème a été mis à jour avec succès.',
+	'THEME_REFRESHED'			=> 'Le thème a été rafraîchi.',
+	'THEME_UPDATED'				=> 'Le thème a été mis à jour.',
 
 	'UNDERLINE'				=> 'Souligné',
 	'UNINSTALLED_IMAGESET'	=> 'Ensembles d’images désinstallés',
