@@ -4,11 +4,9 @@
 * common [French]
 *
 * @package language
-* @version 1.1.1
-* @author Maël Soucaze (Maël Soucaze) <maelsoucaze@phpbb.com> http://mael.soucaze.com/
-* @author Elglobo (Mickaël Salfati) <elglobo@phpbb.com> http://www.phpbb-services.com/
-* @copyright (c) 2005 phpBB Group, 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-license.php GNU Public License
+* @version $Id$
+* @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
+* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
 *
 */
 
@@ -70,16 +68,16 @@ $lang = array_merge($lang, array(
 	'ALL_FORUMS'					=> 'Tous les forums',
 	'ALL_MESSAGES'					=> 'Tous les messages privés',
 	'ALL_POSTS'						=> 'Tous les messages',
-	'ALL_TIMES'						=> 'Les heures sont au format %1$s %2$s',
+	'ALL_TIMES'						=> 'Le fuseau horaire est %1$s %2$s',
 	'ALL_TOPICS'					=> 'Tous les sujets',
 	'AND'							=> 'et',
-	'ARE_WATCHING_FORUM'			=> 'Vous êtes à présent abonné à ce forum. Vous serez averti lorsque de nouveaux sujets seront publiés dans ce dernier.',
-	'ARE_WATCHING_TOPIC'			=> 'Vous êtes à présent abonné à ce sujet. Vous serez averti lorsque de nouveaux messages seront publiés dans ce dernier.',
+	'ARE_WATCHING_FORUM'			=> 'Vous êtes à présent abonné(e) à ce forum. Vous recevrez une notification lorsqu’un nouveau sujet sera publié dans ce dernier.',
+	'ARE_WATCHING_TOPIC'			=> 'Vous êtes à présent abonné(e) à ce sujet. Vous recevrez une notification lorsqu’un nouveau message sera publié dans ce dernier.',
 	'ASCENDING'						=> 'Croissant',
 	'ATTACHMENTS'					=> 'Pièces jointes',
-	'ATTACHED_IMAGE_NOT_IMAGE'		=> 'L’image que vous avez tenté d’insérer est incorrecte.',
+	'ATTACHED_IMAGE_NOT_IMAGE'		=> 'L’image que vous avez essayé d’insérer est incorrecte.',
 	'AUTHOR'						=> 'Auteur',
-	'AUTH_NO_PROFILE_CREATED'		=> 'La création d’un profil utilisateur a échoué.',
+	'AUTH_NO_PROFILE_CREATED'		=> 'La création du profil utilisateur a échoué.',
 	'AVATAR_DISALLOWED_CONTENT'		=> 'Le transfert a été interrompu car le fichier transféré a été identifié comme un vecteur d’attaque possible.',
 	'AVATAR_DISALLOWED_EXTENSION'	=> 'Ce fichier ne peut pas être affiché car l’extension <strong>%s</strong> n’est pas autorisée.',
 	'AVATAR_EMPTY_REMOTE_DATA'		=> 'L’avatar que vous avez spécifié n’a pas pu être transféré car les données à distance semblent corrompues ou incorrectes.',
@@ -102,10 +100,10 @@ $lang = array_merge($lang, array(
 	'BAN_TRIGGERED_BY_USER'	=> 'Votre nom d’utilisateur a été banni.',
 	'BBCODE_GUIDE'			=> 'Guide du BBCode',
 	'BCC'					=> 'Cci ',
-	'BIRTHDAYS'				=> 'Anniversaire(s)',
-	'BOARD_BAN_PERM'		=> 'Vous avez été <strong>définitivement</strong> banni de ce forum.<br /><br />Pour plus d’informations, veuillez contacter l’%2$sadministrateur du forum%3$s.',
+	'BIRTHDAYS'				=> 'Anniversaires',
+	'BOARD_BAN_PERM'		=> 'Vous avez été <strong>définitivement</strong> banni(e) de ce forum.<br /><br />Pour plus d’informations, veuillez contacter l’%2$sadministrateur du forum%3$s.',
 	'BOARD_BAN_REASON'		=> 'Raison du bannissement : <strong>%s</strong>',
-	'BOARD_BAN_TIME'		=> 'Vous avez été banni de ce forum jusqu’au <strong>%1$s</strong>.<br /><br />Pour plus d’informations, veuillez contacter l’%2$sadministrateur du forum%3$s.',
+	'BOARD_BAN_TIME'		=> 'Vous avez été banni(e) de ce forum jusqu’au <strong>%1$s</strong>.<br /><br />Pour plus d’informations, veuillez contacter l’%2$sadministrateur du forum%3$s.',
 	'BOARD_DISABLE'			=> 'Le forum est actuellement indisponible.',
 	'BOARD_DISABLED'		=> 'Le forum est actuellement désactivé.',
 	'BOARD_UNAVAILABLE'		=> 'Le forum est actuellement indisponible. Veuillez réessayer ultérieurement.',
@@ -119,7 +117,7 @@ $lang = array_merge($lang, array(
 	'CHANGE_FONT_SIZE'		=> 'Modifier la taille de la police de caractères',
 	'CHANGING_PREFERENCES'	=> 'Modifie les préférences du forum',
 	'CHANGING_PROFILE'		=> 'Modifie les réglages du profil',
-	'CLICK_VIEW_PRIVMSG'	=> '%sAller à votre boîte de réception%s',
+	'CLICK_VIEW_PRIVMSG'	=> '%sConsulter votre boîte de réception%s',
 	'COLLAPSE_VIEW'			=> 'Réduire',
 	'CLOSE_WINDOW'			=> 'Fermer la fenêtre',
 	'COLOUR_SWATCH'			=> 'Palette de couleurs',
@@ -128,11 +126,11 @@ $lang = array_merge($lang, array(
 	'CONFIRM_CODE'			=> 'Code de confirmation',
 	'CONFIRM_CODE_EXPLAIN'	=> 'Veuillez saisir le code tel qu’il apparaît dans l’image. Toutes les lettres sont insensibles à la casse.',
 	'CONFIRM_CODE_WRONG'	=> 'Le code de confirmation que vous avez saisi est incorrect.',
-	'CONFIRM_OPERATION'		=> 'Êtes-vous sûr de vouloir effectuer cette opération ?',
+	'CONFIRM_OPERATION'		=> 'Êtes-vous sûr(e) de vouloir effectuer cette opération ?',
 	'CONGRATULATIONS'		=> 'Félicitations à ',
 	'CONNECTION_FAILED'		=> 'La connexion a échoué.',
-	'CONNECTION_SUCCESS'	=> 'Vous vous êtes connecté avec succès !',
-	'COOKIES_DELETED'		=> 'Tous les cookies du forum ont été supprimés avec succès.',
+	'CONNECTION_SUCCESS'	=> 'Vous être à présent connecté(e) !',
+	'COOKIES_DELETED'		=> 'Tous les cookies du forum ont été supprimés.',
 	'CURRENT_TIME'			=> 'Nous sommes actuellement le %s',
 
 	'DAY'					=> 'jour',
@@ -167,7 +165,8 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Veuillez spécifier le titre du nouveau message privé.',
 	'ENABLED'							=> 'Activé',
 	'ENCLOSURE'							=> 'Pièce jointe',
-	'ERR_CHANGING_DIRECTORY'			=> 'La modification du répertoire est impossible.',
+	'ENTER_USERNAME'					=> 'Saisissez le nom d’utilisateur',
+	'ERR_CHANGING_DIRECTORY'			=> 'Impossible de modifier le répertoire.',
 	'ERR_CONNECTING_SERVER'				=> 'Une erreur est survenue lors de la connexion au serveur.',
 	'ERR_JAB_AUTH'						=> 'Une erreur est survenue lors de l’authentification au serveur Jabber.',
 	'ERR_JAB_CONNECT'					=> 'Une erreur est survenue lors de la connexion au serveur Jabber.',
@@ -201,33 +200,34 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES'			=> 'Règles du forum ',
 	'FORUM_RULES_LINK'		=> 'Veuillez cliquer ici afin de consulter les règles du forum',
 	'FROM'					=> 'de',
-	'FSOCK_DISABLED'		=> 'L’opération n’a pas pu s’accomplir car la fonction <var>fsockopen</var> a été désactivée ou le serveur interrogé est introuvable.',
+	'FSOCK_DISABLED'		=> 'L’opération n’a pas pu s’effectuer car la fonction <var>fsockopen</var> a été désactivée ou le serveur interrogé est introuvable.',
+	'FSOCK_TIMEOUT'			=> 'Le délai de réponse a expiré lors de la lecture du flux réseau.',
 
 	'FTP_FSOCK_HOST'				=> 'Hôte FTP ',
-	'FTP_FSOCK_HOST_EXPLAIN'		=> 'Le serveur FTP utilisé afin de vous connecter à votre site.',
+	'FTP_FSOCK_HOST_EXPLAIN'		=> 'Le serveur FTP qui est utilisé afin de vous connecter à votre site.',
 	'FTP_FSOCK_PASSWORD'			=> 'Mot de passe FTP ',
-	'FTP_FSOCK_PASSWORD_EXPLAIN'	=> 'Le mot de passe affilié à votre nom d’utilisateur FTP.',
+	'FTP_FSOCK_PASSWORD_EXPLAIN'	=> 'Le mot de passe qui est affilié à votre nom d’utilisateur FTP.',
 	'FTP_FSOCK_PORT'				=> 'Port FTP ',
-	'FTP_FSOCK_PORT_EXPLAIN'		=> 'Le port utilisé afin de vous connecter à votre serveur.',
+	'FTP_FSOCK_PORT_EXPLAIN'		=> 'Le port qui est utilisé afin de vous connecter à votre serveur.',
 	'FTP_FSOCK_ROOT_PATH'			=> 'Chemin vers phpBB ',
 	'FTP_FSOCK_ROOT_PATH_EXPLAIN'	=> 'Le chemin de la racine vers votre forum phpBB.',
 	'FTP_FSOCK_TIMEOUT'				=> 'Délai d’attente FTP ',
 	'FTP_FSOCK_TIMEOUT_EXPLAIN'		=> 'La durée de temps, en secondes, que le système attendra afin d’obtenir une réponse de votre serveur.',
 	'FTP_FSOCK_USERNAME'			=> 'Nom d’utilisateur FTP ',
-	'FTP_FSOCK_USERNAME_EXPLAIN'	=> 'Le nom d’utilisateur utilisé afin de vous connecter à votre serveur.',
+	'FTP_FSOCK_USERNAME_EXPLAIN'	=> 'Le nom d’utilisateur qui est utilisé afin de vous connecter à votre serveur.',
 
 	'FTP_HOST'					=> 'Hôte FTP ',
-	'FTP_HOST_EXPLAIN'			=> 'Le serveur FTP utilisé afin de vous connecter à votre site.',
+	'FTP_HOST_EXPLAIN'			=> 'Le serveur FTP qui est utilisé afin de vous connecter à votre site.',
 	'FTP_PASSWORD'				=> 'Mot de passe FTP ',
-	'FTP_PASSWORD_EXPLAIN'		=> 'Le mot de passe affilié à votre nom d’utilisateur FTP.',
+	'FTP_PASSWORD_EXPLAIN'		=> 'Le mot de passe qui est affilié à votre nom d’utilisateur FTP.',
 	'FTP_PORT'					=> 'Port FTP ',
-	'FTP_PORT_EXPLAIN'			=> 'Le port utilisé afin de vous connecter à votre serveur.',
+	'FTP_PORT_EXPLAIN'			=> 'Le port qui est utilisé afin de vous connecter à votre serveur.',
 	'FTP_ROOT_PATH'				=> 'Chemin vers phpBB ',
 	'FTP_ROOT_PATH_EXPLAIN'		=> 'Le chemin de la racine vers votre forum phpBB.',
 	'FTP_TIMEOUT'				=> 'Délai d’attente FTP ',
 	'FTP_TIMEOUT_EXPLAIN'		=> 'La durée de temps, en secondes, que le système attendra afin d’obtenir une réponse de votre serveur.',
 	'FTP_USERNAME'				=> 'Nom d’utilisateur FTP ',
-	'FTP_USERNAME_EXPLAIN'		=> 'Le nom d’utilisateur utilisé afin de vous connecter à votre serveur.',
+	'FTP_USERNAME_EXPLAIN'		=> 'Le nom d’utilisateur qui est utilisé afin de vous connecter à votre serveur.',
 
 	'GENERAL_ERROR'				=> 'Erreur générale',
 	'GB'						=> 'Go',
@@ -273,7 +273,7 @@ $lang = array_merge($lang, array(
 	'IF'						=> 'Si ',
 	'IMAGE'						=> 'Image',
 	'IMAGE_FILETYPE_INVALID'	=> 'Les images de type %d concernant le standard MIME %s ne sont pas supportées.',
-	'IMAGE_FILETYPE_MISMATCH'	=> 'Le type de l’image ne correspond pas. L’extension %1$s était attendue mais l’extension %2$s a été fournie.',
+	'IMAGE_FILETYPE_MISMATCH'	=> 'Le type de l’image ne correspond pas. L’extension %1$s était attendue mais l’extension %2$s a été spécifiée.',
 	'IN'						=> 'dans',
 	'INDEX'						=> 'Page d’index',
 	'INFORMATION'				=> 'Information',
@@ -284,7 +284,7 @@ $lang = array_merge($lang, array(
 	'IP_BLACKLISTED'			=> 'Votre adresse IP %1$s a été bloquée car elle apparaît dans la liste noire. Pour plus d’informations, veuillez consulter <a href="%2$s">%2$s</a>.',
 
 	'JABBER'				=> 'Jabber ',
-	'JOINED'				=> 'Inscrit le ',
+	'JOINED'				=> 'Inscrit(e) le ',
 	'JUMP_PAGE'				=> 'Saisissez le numéro de la page que vous souhaitez atteindre',
 	'JUMP_TO'				=> 'Aller vers ',
 	'JUMP_TO_PAGE'			=> 'Cliquez afin d’aller vers la page…',
@@ -306,17 +306,17 @@ $lang = array_merge($lang, array(
 	'LOGIN'								=> 'Connexion',
 	'LOGIN_CHECK_PM'					=> 'Connectez-vous afin de consulter vos messages privés.',
 	'LOGIN_CONFIRMATION'				=> 'Confirmation de connexion',
-	'LOGIN_CONFIRM_EXPLAIN'				=> 'Afin d’empêcher tout acte malveillant, vous devez saisir un code de confirmation après avoir échoué un certain nombre de fois lors de vos tentatives de connexion. Le code est affiché dans l’image que vous devriez voir ci-dessous. Si vous êtes visuellement déficient ou que vous éprouvez des difficultés à lire ce code correctement, veuillez contacter l’%sadministrateur du forum%s.', // Unused
-	'LOGIN_ERROR_ATTEMPTS'				=> 'Vous avez dépassé le nombre maximum de tentatives de connexion autorisé. En plus de votre nom d’utilisateur et de votre mot de passe, vous devez à présent compléter le CAPTCHA que vous devriez voir ci-dessous.',
-	'LOGIN_ERROR_EXTERNAL_AUTH_APACHE'	=> 'Vous n’avez pas été authentifié par Apache.',
+	'LOGIN_CONFIRM_EXPLAIN'				=> 'Afin d’empêcher tout acte malveillant, vous devez saisir un code de confirmation après avoir échoué un certain nombre de fois lors de vos tentatives de connexion. Le code est affiché dans l’image que vous devriez apercevoir ci-dessous. Si vous êtes visuellement déficient(e) ou que vous éprouvez des difficultés à lire ce code correctement, veuillez contacter l’%sadministrateur du forum%s.', // Unused
+	'LOGIN_ERROR_ATTEMPTS'				=> 'Vous avez dépassé le nombre maximum de tentatives de connexion autorisé. En plus de votre nom d’utilisateur et de votre mot de passe, vous devez à présent compléter le CAPTCHA que vous devriez apercevoir ci-dessous.',
+	'LOGIN_ERROR_EXTERNAL_AUTH_APACHE'	=> 'Vous n’avez pas été authentifié(e) par Apache.',
 	'LOGIN_ERROR_PASSWORD'				=> 'Vous avez spécifié un mot de passe incorrect. Veuillez vérifier votre mot de passe, puis réessayer. Si ce problème persiste, veuillez contacter l’%sadministrateur du forum%s.',
 	'LOGIN_ERROR_PASSWORD_CONVERT'		=> 'Il n’a pas été possible de convertir votre mot de passe lors de la mise à jour de ce logiciel de forum. Veuillez %sdemander un nouveau mot de passe%s. Si ce problème persiste, veuillez contacter l’%sadministrateur du forum%s.',
 	'LOGIN_ERROR_USERNAME'				=> 'Vous avez spécifié un nom d’utilisateur incorrect. Veuillez vérifier votre nom d’utilisateur, puis réessayer. Si ce problème persiste, veuillez contacter l’%sadministrateur du forum%s.',
 	'LOGIN_FORUM'						=> 'Vous devez saisir le mot de passe de ce forum afin de pouvoir consulter ou publier des sujets et des messages.',
-	'LOGIN_INFO'						=> 'Vous devez être inscrit avant de pouvoir vous connecter. L’inscription est rapide et vous offre de nombreux avantages. Par exemple, l’administrateur du forum peut accorder des fonctionnalités supplémentaires aux utilisateurs inscrits. Avant de vous inscrire, assurez-vous d’avoir pris connaissance de nos conditions d’utilisation et de notre politique de confidentialité. Veuillez également consulter attentivement toutes les règles du forum lors de votre navigation.',
-	'LOGIN_VIEWFORUM'					=> 'Vous devez être inscrit et être connecté avant de pouvoir consulter ce forum.',
-	'LOGIN_EXPLAIN_EDIT'				=> 'Vous devez être inscrit et être connecté avant de pouvoir éditer les messages de ce forum.',
-	'LOGIN_EXPLAIN_VIEWONLINE'			=> 'Vous devez être inscrit et être connecté avant de pouvoir consulter la liste des utilisateurs en ligne.',
+	'LOGIN_INFO'						=> 'Vous devez être inscrit(e) avant de pouvoir vous connecter. L’inscription est rapide et vous offre de nombreux avantages. Par exemple, l’administrateur du forum peut accorder des fonctionnalités supplémentaires aux utilisateurs inscrits. Avant de vous inscrire, assurez-vous d’avoir pris connaissance de nos conditions d’utilisation et de notre politique de confidentialité. Veuillez également consulter attentivement toutes les règles du forum lors de votre navigation.',
+	'LOGIN_VIEWFORUM'					=> 'Vous devez être inscrit(e) et connecté(e) avant de pouvoir consulter ce forum.',
+	'LOGIN_EXPLAIN_EDIT'				=> 'Vous devez être inscrit(e) et connecté(e) avant de pouvoir éditer les messages de ce forum.',
+	'LOGIN_EXPLAIN_VIEWONLINE'			=> 'Vous devez être inscrit(e) et connecté(e) avant de pouvoir consulter la liste des utilisateurs en ligne.',
 	'LOGOUT'							=> 'Déconnexion',
 	'LOGOUT_USER'						=> 'Déconnexion [ %s ]',
 	'LOG_ME_IN'							=> 'Me connecter automatiquement lors de chaque visite',
@@ -356,18 +356,18 @@ $lang = array_merge($lang, array(
 	'NEXT_STEP'					=> 'Suivant',
 	'NEVER'						=> 'Jamais',
 	'NO'						=> 'Non',
-	'NOT_ALLOWED_MANAGE_GROUP'	=> 'Vous n’êtes pas autorisé à gérer ce groupe.',
-	'NOT_AUTHORISED'			=> 'Vous n’êtes pas autorisé à accéder à cette partie.',
-	'NOT_WATCHING_FORUM'		=> 'Vous n’êtes à présent plus abonné à ce forum. Vous ne serez plus averti(e) lorsque de nouveaux sujets seront publiés dans ce dernier.',
-	'NOT_WATCHING_TOPIC'		=> 'Vous n’êtes à présent plus abonné à ce sujet. Vous ne serez plus averti(e) lorsque de nouveaux messages seront publiés dans ce dernier.',
-	'NOTIFY_ADMIN'				=> 'Veuillez avertir l’administrateur du forum ou le webmestre.',
-	'NOTIFY_ADMIN_EMAIL'		=> 'Veuillez avertir l’administrateur du forum ou le webmestre : <a href="mailto:%1$s">%1$s</a>',
-	'NO_ACCESS_ATTACHMENT'		=> 'Vous n’êtes pas autorisé à accéder à ce fichier.',
+	'NOT_ALLOWED_MANAGE_GROUP'	=> 'Vous n’êtes pas autorisé(e) à gérer ce groupe.',
+	'NOT_AUTHORISED'			=> 'Vous n’êtes pas autorisé(e) à accéder à cette partie.',
+	'NOT_WATCHING_FORUM'		=> 'Vous n’êtes à présent plus abonné(e) à ce forum. Vous ne recevrez plus de notification lorsqu’un nouveau sujet sera publié dans ce dernier.',
+	'NOT_WATCHING_TOPIC'		=> 'Vous n’êtes à présent plus abonné(e) à ce sujet. Vous ne recevrez plus de notification lorsqu’un nouveau message sera publié dans ce dernier.',
+	'NOTIFY_ADMIN'				=> 'Veuillez contacter l’administrateur du forum ou le webmestre.',
+	'NOTIFY_ADMIN_EMAIL'		=> 'Veuillez contacter l’administrateur du forum ou le webmestre : <a href="mailto:%1$s">%1$s</a>',
+	'NO_ACCESS_ATTACHMENT'		=> 'Vous n’êtes pas autorisé(e) à accéder à ce fichier.',
 	'NO_ACTION'					=> 'Aucune action n’a été spécifiée.',
 	'NO_ADMINISTRATORS'			=> 'Il n’y a aucun administrateur.',
-	'NO_AUTH_ADMIN'				=> 'Vous n’êtes pas autorisé à accéder au panneau de contrôle d’administration.',
-	'NO_AUTH_ADMIN_USER_DIFFER'	=> 'Vous n’êtes pas autorisé à vous authentifier de nouveau avec un compte utilisateur différent au vôtre.',
-	'NO_AUTH_OPERATION'			=> 'Vous n’avez pas les permissions appropriées afin d’accomplir cette opération.',
+	'NO_AUTH_ADMIN'				=> 'Vous n’êtes pas autorisé(e) à accéder au panneau de contrôle d’administration.',
+	'NO_AUTH_ADMIN_USER_DIFFER'	=> 'Vous n’êtes pas autorisé(e) à vous authentifier de nouveau avec un compte utilisateur différent au vôtre.',
+	'NO_AUTH_OPERATION'			=> 'Vous ne détenez pas les permissions appropriées afin d’effectuer cette opération.',
 	'NO_CONNECT_TO_SMTP_HOST'	=> 'Impossible de se connecter à l’hôte SMTP : %1$s : %2$s',
 	'NO_BIRTHDAYS'				=> 'Aucun membre ne fête son anniversaire aujourd’hui.',
 	'NO_EMAIL_MESSAGE'			=> 'Le contenu du message de ce courriel était vide.',
@@ -387,7 +387,7 @@ $lang = array_merge($lang, array(
 	'NO_NEW_POSTS'				=> 'Aucun nouveau message',	// Not used anymore
 	'NO_ONLINE_USERS'			=> 'Aucun utilisateur inscrit',
 	'NO_POSTS'					=> 'Aucun message',
-	'NO_POSTS_TIME_FRAME'		=> 'Aucun message n’a été publié dans ce sujet dans la période spécifiée.',
+	'NO_POSTS_TIME_FRAME'		=> 'Aucun message n’a été publié dans ce sujet lors de la période spécifiée.',
 	'NO_FEED_ENABLED'			=> 'Les flux ne sont pas disponibles sur ce forum.',
 	'NO_FEED'					=> 'Le flux que vous recherchez n’est pas disponible.',
 	'NO_SUBJECT'				=> 'Aucun sujet n’a été spécifié',								// Used for posts having no subject defined but displayed within management pages.
@@ -438,11 +438,11 @@ $lang = array_merge($lang, array(
 	'POSTS_UNAPPROVED'		=> 'Au moins un message de ce sujet n’a pas été approuvé.',
 	'POST_BY_AUTHOR'		=> 'par',
 	'POST_BY_FOE'			=> 'Ce message a été publié par <strong>%1$s</strong> qui est actuellement dans votre liste d’utilisateurs ignorés. %2$sAfficher ce message%3$s.',
-	'POST_DAY'				=> '%.2f messages par jour',
+	'POST_DAY'				=> '%.2f message(s) par jour',
 	'POST_DETAILS'			=> 'Informations sur le message',
 	'POST_NEW_TOPIC'		=> 'Publier un nouveau sujet',
 	'POST_PCT'				=> '%.2f%% du nombre total de messages',
-	'POST_PCT_ACTIVE'		=> '%.2f%% du nombre total des messages de l’utilisateur',
+	'POST_PCT_ACTIVE'		=> '%.2f%% du nombre total de messages de l’utilisateur',
 	'POST_PCT_ACTIVE_OWN'	=> '%.2f%% de votre nombre total de messages',
 	'POST_REPLY'			=> 'Publier une réponse',
 	'POST_REPORTED'			=> 'Cliquez ici afin de consulter le rapport',
@@ -469,7 +469,7 @@ $lang = array_merge($lang, array(
 	'REDIRECT'					=> 'Redirection',
 	'REDIRECTS'					=> 'Nombre total de redirections',
 	'REGISTER'					=> 'Inscription',
-	'REGISTERED_USERS'			=> 'Utilisateurs inscrits :',
+	'REGISTERED_USERS'			=> 'Utilisateur(s) inscrit(s) :',
 	'REG_USERS_ONLINE'			=> 'Il y a %d utilisateurs inscrits et ',
 	'REG_USERS_TOTAL'			=> '%d inscrits, ',
 	'REG_USERS_TOTAL_AND'		=> '%d inscrits et ',
@@ -481,7 +481,7 @@ $lang = array_merge($lang, array(
 	'REG_USER_TOTAL_AND'		=> '%d inscrit et ',
 	'REMOVE'					=> 'Supprimer',
 	'REMOVE_INSTALL'			=> 'Veuillez supprimer, déplacer ou renommer le répertoire « install » avant d’utiliser votre forum. Tant que ce répertoire est présent, vous n’aurez accès qu’au panneau de contrôle d’administration.',
-	'REPLIES'					=> 'Réponses',
+	'REPLIES'					=> 'Réponse(s)',
 	'REPLY_WITH_QUOTE'			=> 'Répondre en citant',
 	'REPLYING_GLOBAL_ANNOUNCE'	=> 'Répond à une annonce globale',
 	'REPLYING_MESSAGE'			=> 'Répond à un message dans %s',
@@ -521,7 +521,7 @@ $lang = array_merge($lang, array(
 	'SEARCH_MINI'				=> 'Rechercher…',
 	'SEARCH_ADV'				=> 'Recherche avancée',
 	'SEARCH_ADV_EXPLAIN'		=> 'Accéder aux options de la recherche avancée',
-	'SEARCH_KEYWORDS'			=> 'Rechercher par mot(s)-clé(s) ',
+	'SEARCH_KEYWORDS'			=> 'Rechercher par mots-clés ',
 	'SEARCHING_FORUMS'			=> 'Recherche dans les forums',
 	'SEARCH_ACTIVE_TOPICS'		=> 'Consulter les sujets actifs',
 	'SEARCH_FOR'				=> 'Recherche de',
@@ -545,8 +545,8 @@ $lang = array_merge($lang, array(
 	'SIGNATURE'					=> 'Signature',
 	'SKIP'						=> 'Accéder au contenu',
 	'SMTP_NO_AUTH_SUPPORT'		=> 'Le serveur SMTP ne supporte pas l’authentification.',
-	'SORRY_AUTH_READ'			=> 'Vous n’êtes pas autorisé à consulter ce forum.',
-	'SORRY_AUTH_VIEW_ATTACH'	=> 'Vous n’êtes pas autorisé à télécharger cette pièce jointe.',
+	'SORRY_AUTH_READ'			=> 'Vous n’êtes pas autorisé(e) à consulter ce forum.',
+	'SORRY_AUTH_VIEW_ATTACH'	=> 'Vous n’êtes pas autorisé(e) à télécharger cette pièce jointe.',
 	'SORT_BY'					=> 'Trier par ',
 	'SORT_JOINED'				=> 'Date d’inscription',
 	'SORT_LOCATION'				=> 'Localisation',
@@ -616,8 +616,8 @@ $lang = array_merge($lang, array(
 	'TOO_SHORT_WEBSITE'				=> 'L’adresse du site internet que vous avez spécifiée est trop courte.',
 	'TOO_SHORT_YIM'					=> 'Le nom d’utilisateur Yahoo! Messenger que vous avez spécifié est trop court.',
 
-	'TOO_SMALL'						=> 'La valeur que vous avez saisie est trop petite.',
-	'TOO_SMALL_MAX_RECIPIENTS'		=> 'La valeur du réglage <strong>Nombre maximum de destinataires autorisés par message privé</strong> que vous avez saisie est trop petite.',
+	'TOO_SMALL'						=> 'La valeur que vous avez saisie est trop faible.',
+	'TOO_SMALL_MAX_RECIPIENTS'		=> 'La valeur du réglage <strong>Nombre maximum de destinataires autorisés par message privé</strong> que vous avez saisie est trop faible.',
 
 	'TOPIC'				=> 'Sujet ',
 	'TOPICS'			=> 'Sujet(s)',
@@ -654,9 +654,13 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> messages non lus',
 	'UNREAD_POST'			=> 'Message non lu',
 	'UNREAD_POSTS'			=> 'Messages non lus',
-	'UNWATCHED_FORUMS'			=> 'Vous n’êtes à présent plus abonné aux forums sélectionnés.',
-	'UNWATCHED_TOPICS'			=> 'Vous n’êtes à présent plus abonné aux sujets sélectionnés.',
-	'UNWATCHED_FORUMS_TOPICS'	=> 'Vous n’êtes à présent plus abonné aux entrées sélectionnées.',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir vous désabonner de ce forum ?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Êtes-vous sûr(e) de vouloir vous désabonner du forum « %s » ?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir vous désabonner de ce sujet ?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Êtes-vous sûr(e) de vouloir vous désabonner du sujet « %s » ?',
+	'UNWATCHED_FORUMS'			=> 'Vous n’êtes à présent plus abonné(e) aux forums sélectionnés.',
+	'UNWATCHED_TOPICS'			=> 'Vous n’êtes à présent plus abonné(e) aux sujets sélectionnés.',
+	'UNWATCHED_FORUMS_TOPICS'	=> 'Vous n’êtes à présent plus abonné(e) aux éléments sélectionnées.',
 	'UPDATE'				=> 'Mettre à jour',
 	'UPLOAD_IN_PROGRESS'	=> 'Transfert en cours.',
 	'URL_REDIRECT'			=> 'Si votre navigateur ne supporte pas les redirections automatiques, veuillez %scliquer ici%s afin d’être redirigé.',
@@ -670,7 +674,7 @@ $lang = array_merge($lang, array(
 	'USERS'					=> 'Utilisateurs',
 	'USE_PERMISSIONS'		=> 'Tester les permissions de l’utilisateur',
 
-	'USER_NEW_PERMISSION_DISALLOWED'	=> 'Vous n’êtes pas autorisé à utiliser cette fonctionnalité. Pour l’être, vous devez simplement vous inscrire et participer de manière plus active.',
+	'USER_NEW_PERMISSION_DISALLOWED'	=> 'Vous n’êtes pas autorisé(e) à utiliser cette fonctionnalité. Pour l’être, vous devez simplement vous inscrire et participer de manière plus active.',
 
 	'VARIANT_DATE_SEPARATOR'	=> ' / ',	// Used in date format dropdown, eg: "Today, 13:37 / 01 Jan 2007, 13:37" ... to join a relative date with calendar date
 	'VIEWED'					=> 'Consulté',
@@ -682,9 +686,9 @@ $lang = array_merge($lang, array(
 	'VIEWING_PRIVATE_MESSAGES'	=> 'Consulte ses messages privés',
 	'VIEWING_REGISTER'			=> 'Inscrit un compte',
 	'VIEWING_UCP'				=> 'Consulte le panneau de contrôle de l’utilisateur',
-	'VIEWS'						=> 'Vues',
+	'VIEWS'						=> 'Consultation(s)',
 	'VIEW_BOOKMARKS'			=> 'Consulter les signets',
-	'VIEW_FORUM_LOGS'			=> 'Consulter les historiques',
+	'VIEW_FORUM_LOGS'			=> 'Consulter l’historique',
 	'VIEW_LATEST_POST'			=> 'Consulter le dernier message',
 	'VIEW_NEWEST_POST'			=> 'Consulter le message non lu le plus récent',
 	'VIEW_NOTES'				=> 'Consulter les notes sur l’utilisateur',
@@ -694,7 +698,7 @@ $lang = array_merge($lang, array(
 	'VIEW_TOPIC_ANNOUNCEMENT'	=> 'Annonce : ',
 	'VIEW_TOPIC_GLOBAL'			=> 'Annonce globale : ',
 	'VIEW_TOPIC_LOCKED'			=> 'Verrouillé : ',
-	'VIEW_TOPIC_LOGS'			=> 'Consulter les historiques',
+	'VIEW_TOPIC_LOGS'			=> 'Consulter l’historique',
 	'VIEW_TOPIC_MOVED'			=> 'Déplacé : ',
 	'VIEW_TOPIC_POLL'			=> 'Sondage : ',
 	'VIEW_TOPIC_STICKY'			=> 'Note : ',
@@ -702,6 +706,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Avertissement(s) ',
 	'WARN_USER'			=> 'Avertir l’utilisateur',
+	'WATCH_FORUM_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir vous abonner à ce forum ?',
+	'WATCH_FORUM_DETAILED'	=> 'Êtes-vous sûr(e) de vouloir vous abonner au forum « %s » ?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir vous abonner à ce sujet ?',
+	'WATCH_TOPIC_DETAILED'	=> 'Êtes-vous sûr(e) de vouloir vous abonner au sujet « %s » ?',
 	'WELCOME_SUBJECT'	=> 'Bienvenue sur les forums de %s',
 	'WEBSITE'			=> 'Site internet ',
 	'WHOIS'				=> 'Qui est-ce ?',
@@ -719,9 +727,9 @@ $lang = array_merge($lang, array(
 	'YES'				=> 'Oui',
 	'YIM'				=> 'YIM ',
 	'YOU_LAST_VISIT'	=> 'Dernière visite le : %s',
-	'YOU_NEW_PM'		=> 'Un nouveau message privé vous attend dans votre boîte de réception.',
-	'YOU_NEW_PMS'		=> 'De nouveaux messages privés vous attendent dans votre boîte de réception.',
-	'YOU_NO_NEW_PM'		=> 'Aucun nouveau message privé ne vous attend dans votre boîte de réception.',
+	'YOU_NEW_PM'		=> 'Vous avez un nouveau message privé dans votre boîte de réception.',
+	'YOU_NEW_PMS'		=> 'Vous avez de nouveaux messages privés dans votre boîte de réception.',
+	'YOU_NO_NEW_PM'		=> 'Vous n’avez aucun nouveau message privé dans votre boîte de réception.',
 
 	'datetime'			=> array(
 		'TODAY'		=> 'Aujourd’hui',
@@ -778,90 +786,90 @@ $lang = array_merge($lang, array(
 	),
 
 	'tz'				=> array(
-		'-12'	=> 'UTC - 12 heures',
-		'-11'	=> 'UTC - 11 heures',
-		'-10'	=> 'UTC - 10 heures',
-		'-9.5'	=> 'UTC - 9:30 heures',
-		'-9'	=> 'UTC - 9 heures',
-		'-8'	=> 'UTC - 8 heures',
-		'-7'	=> 'UTC - 7 heures',
-		'-6'	=> 'UTC - 6 heures',
-		'-5'	=> 'UTC - 5 heures',
-		'-4.5'	=> 'UTC - 4:30 heures',
-		'-4'	=> 'UTC - 4 heures',
-		'-3.5'	=> 'UTC - 3:30 heures',
-		'-3'	=> 'UTC - 3 heures',
-		'-2'	=> 'UTC - 2 heures',
-		'-1'	=> 'UTC - 1 heure',
+		'-12'	=> 'UTC-12 heures',
+		'-11'	=> 'UTC-11 heures',
+		'-10'	=> 'UTC-10 heures',
+		'-9.5'	=> 'UTC-9:30 heures',
+		'-9'	=> 'UTC-9 heures',
+		'-8'	=> 'UTC-8 heures',
+		'-7'	=> 'UTC-7 heures',
+		'-6'	=> 'UTC-6 heures',
+		'-5'	=> 'UTC-5 heures',
+		'-4.5'	=> 'UTC-4:30 heures',
+		'-4'	=> 'UTC-4 heures',
+		'-3.5'	=> 'UTC-3:30 heures',
+		'-3'	=> 'UTC-3 heures',
+		'-2'	=> 'UTC-2 heures',
+		'-1'	=> 'UTC-1 heure',
 		'0'		=> 'UTC',
-		'1'		=> 'UTC + 1 heure',
-		'2'		=> 'UTC + 2 heures',
-		'3'		=> 'UTC + 3 heures',
-		'3.5'	=> 'UTC + 3:30 heures',
-		'4'		=> 'UTC + 4 heures',
-		'4.5'	=> 'UTC + 4:30 heures',
-		'5'		=> 'UTC + 5 heures',
-		'5.5'	=> 'UTC + 5:30 heures',
-		'5.75'	=> 'UTC + 5:45 heures',
-		'6'		=> 'UTC + 6 heures',
-		'6.5'	=> 'UTC + 6:30 heures',
-		'7'		=> 'UTC + 7 heures',
-		'8'		=> 'UTC + 8 heures',
-		'8.75'	=> 'UTC + 8:45 heures',
-		'9'		=> 'UTC + 9 heures',
-		'9.5'	=> 'UTC + 9:30 heures',
-		'10'	=> 'UTC + 10 heures',
-		'10.5'	=> 'UTC + 10:30 heures',
-		'11'	=> 'UTC + 11 heures',
-		'11.5'	=> 'UTC + 11:30 heures',
-		'12'	=> 'UTC + 12 heures',
-		'12.75'	=> 'UTC + 12:45 heures',
-		'13'	=> 'UTC + 13 heures',
-		'14'	=> 'UTC + 14 heures',
-		'dst'	=> '[ Heure d’été ]',
+		'1'		=> 'UTC+1 heure',
+		'2'		=> 'UTC+2 heures',
+		'3'		=> 'UTC+3 heures',
+		'3.5'	=> 'UTC+3:30 heures',
+		'4'		=> 'UTC+4 heures',
+		'4.5'	=> 'UTC+4:30 heures',
+		'5'		=> 'UTC+5 heures',
+		'5.5'	=> 'UTC+5:30 heures',
+		'5.75'	=> 'UTC+5:45 heures',
+		'6'		=> 'UTC+6 heures',
+		'6.5'	=> 'UTC+6:30 heures',
+		'7'		=> 'UTC+7 heures',
+		'8'		=> 'UTC+8 heures',
+		'8.75'	=> 'UTC+8:45 heures',
+		'9'		=> 'UTC+9 heures',
+		'9.5'	=> 'UTC+9:30 heures',
+		'10'	=> 'UTC+10 heures',
+		'10.5'	=> 'UTC+10:30 heures',
+		'11'	=> 'UTC+11 heures',
+		'11.5'	=> 'UTC+11:30 heures',
+		'12'	=> 'UTC+12 heures',
+		'12.75'	=> 'UTC+12:45 heures',
+		'13'	=> 'UTC+13 heures',
+		'14'	=> 'UTC+14 heures',
+		'dst'	=> '[Heure d’été]',
 	),
 
 	'tz_zones'	=> array(
-		'-12'	=> '[UTC - 12] Île Baker',
-		'-11'	=> '[UTC - 11] Niue, Samoa',
-		'-10'	=> '[UTC - 10] Hawaii-Aleutian, Île Cook',
-		'-9.5'	=> '[UTC - 9:30] Îles Marquises',
-		'-9'	=> '[UTC - 9] Alaska, Île Gambier',
-		'-8'	=> '[UTC - 8] Pacifique',
-		'-7'	=> '[UTC - 7] Montagnes Rocheuses',
-		'-6'	=> '[UTC - 6] Centre',
-		'-5'	=> '[UTC - 5] Est',
-		'-4.5'	=> '[UTC - 4:30] Venezuela',
-		'-4'	=> '[UTC - 4] Atlantique',
-		'-3.5'	=> '[UTC - 3:30] Terre-Neuve',
-		'-3'	=> '[UTC - 3] Amazonie, Groenland central',
-		'-2'	=> '[UTC - 2] Fernando de Noronha, Géorgie du sud &amp; les Îles Sandwich du sud',
-		'-1'	=> '[UTC - 1] Açores, Cap-Vert, Groenland de l’est',
+		'-12'	=> '[UTC-12] Île Baker',
+		'-11'	=> '[UTC-11] Niue, Samoa',
+		'-10'	=> '[UTC-10] Hawaii-Aleutian, Île Cook',
+		'-9.5'	=> '[UTC-9:30] Îles Marquises',
+		'-9'	=> '[UTC-9] Alaska, Île Gambier',
+		'-8'	=> '[UTC-8] Pacifique',
+		'-7'	=> '[UTC-7] Montagnes Rocheuses',
+		'-6'	=> '[UTC-6] Centre',
+		'-5'	=> '[UTC-5] Est',
+		'-4.5'	=> '[UTC-4:30] Venezuela',
+		'-4'	=> '[UTC-4] Atlantique',
+		'-3.5'	=> '[UTC-3:30] Terre-Neuve',
+		'-3'	=> '[UTC-3] Amazonie, Groenland central',
+		'-2'	=> '[UTC-2] Fernando de Noronha, Géorgie du sud &amp; les Îles Sandwich du sud',
+		'-1'	=> '[UTC-1] Açores, Cap-Vert, Groenland de l’est',
 		'0'		=> '[UTC] Europe de l’ouest, Méridien de Greenwich',
-		'1'		=> '[UTC + 1] Europe centrale, Afrique de l’ouest',
-		'2'		=> '[UTC + 2] Europe de l’est, Afrique centrale',
-		'3'		=> '[UTC + 3] Moscou, Afrique de l’est',
-		'3.5'	=> '[UTC + 3:30] Iran',
-		'4'		=> '[UTC + 4] Gulf, Samara',
-		'4.5'	=> '[UTC + 4:30] Afghanistan',
-		'5'		=> '[UTC + 5] Pakistan, Iekaterinbourg',
-		'5.5'	=> '[UTC + 5:30] Inde, Sri Lanka',
-		'5.75'	=> '[UTC + 5:45] Népal',
-		'6'		=> '[UTC + 6] Bangladesh, Bhoutan, Novosibirsk',
-		'6.5'	=> '[UTC + 6:30] Îles Cocos, Myanmar',
-		'7'		=> '[UTC + 7] Indochine, Krasnoyarsk',
-		'8'		=> '[UTC + 8] Chine, Australie de l’ouest, Irkutsk',
-		'8.75'	=> '[UTC + 8:45] Australie du sud-est',
-		'9'		=> '[UTC + 9] Japon, Corée, Chita',
-		'9.5'	=> '[UTC + 9:30] Australie centrale',
-		'10'	=> '[UTC + 10] Australie de l’est, Vladivostok',
-		'10.5'	=> '[UTC + 10:30] Lord Howe',
-		'11'	=> '[UTC + 11] Île Solomon, Magadan',
-		'11.5'	=> '[UTC + 11:30] Île Norfolk',
-		'12'	=> '[UTC + 12] Nouvelle Zélande, Fiji, Kamchatka',
-		'12.75'	=> '[UTC + 12:45] Îles Chatham',
-		'13'	=> '[UTC + 13] Tongo, Îles Phoenix',
-		'14'	=> '[UTC + 14] Île de Wight',
+		'1'		=> '[UTC+1] Europe centrale, Afrique de l’ouest',
+		'2'		=> '[UTC+2] Europe de l’est, Afrique centrale',
+		'3'		=> '[UTC+3] Moscou, Afrique de l’est',
+		'3.5'	=> '[UTC+3:30] Iran',
+		'4'		=> '[UTC+4] Gulf, Samara',
+		'4.5'	=> '[UTC+4:30] Afghanistan',
+		'5'		=> '[UTC+5] Pakistan, Iekaterinbourg',
+		'5.5'	=> '[UTC+5:30] Inde, Sri Lanka',
+		'5.75'	=> '[UTC+5:45] Népal',
+		'6'		=> '[UTC+6] Bangladesh, Bhoutan, Novosibirsk',
+		'6.5'	=> '[UTC+6:30] Îles Cocos, Myanmar',
+		'7'		=> '[UTC+7] Indochine, Krasnoyarsk',
+		'8'		=> '[UTC+8] Chine, Australie de l’ouest, Irkutsk',
+		'8.75'	=> '[UTC+8:45] Australie du sud-est',
+		'9'		=> '[UTC+9] Japon, Corée, Chita',
+		'9.5'	=> '[UTC+9:30] Australie centrale',
+		'10'	=> '[UTC+10] Australie de l’est, Vladivostok',
+		'10.5'	=> '[UTC+10:30] Lord Howe',
+		'11'	=> '[UTC+11] Île Solomon, Magadan',
+		'11.5'	=> '[UTC+11:30] Île Norfolk',
+		'12'	=> '[UTC+12] Nouvelle Zélande, Fiji, Kamchatka',
+		'12.75'	=> '[UTC+12:45] Îles Chatham',
+		'13'	=> '[UTC+13] Tongo, Îles Phoenix',
+		'14'	=> '[UTC+14] Île de Wight',
 	),
 
 	// The value is only an example and will get replaced by the current time on view
