@@ -4,11 +4,9 @@
 * mcp [French]
 *
 * @package language
-* @version 1.1.1
-* @author Maël Soucaze (Maël Soucaze) <maelsoucaze@phpbb.com> http://mael.soucaze.com/
-* @author Elglobo (Mickaël Salfati) <elglobo@phpbb.com> http://www.phpbb-services.com/
-* @copyright (c) 2005 phpBB Group, 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-license.php GNU Public License
+* @version $Id$
+* @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
+* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
 *
 */
 
@@ -44,17 +42,17 @@ $lang = array_merge($lang, array(
 	'ADD_FEEDBACK_EXPLAIN'	=> 'Si vous souhaitez ajouter une remarque, veuillez compléter le formulaire suivant. N’utilisez que du texte brut ; l’HTML, le BBCode, etc. ne sont pas autorisés.',
 	'ADD_WARNING'			=> 'Ajouter un avertissement',
 	'ADD_WARNING_EXPLAIN'	=> 'Si vous souhaitez envoyer un avertissement à cet utilisateur, veuillez compléter le formulaire suivant. N’utilisez que du texte brut ; l’HTML, le BBCode, etc. ne sont pas autorisés.',
-	'ALL_ENTRIES'			=> 'Toutes les entrées',
-	'ALL_NOTES_DELETED'		=> 'Toutes les notes sur cet utilisateur ont été supprimées avec succès.',
+	'ALL_ENTRIES'			=> 'Tous les éléments',
+	'ALL_NOTES_DELETED'		=> 'Toutes les notes sur cet utilisateur ont été supprimées.',
 	'ALL_REPORTS'			=> 'Tous les rapports',
 	'ALREADY_REPORTED'		=> 'Ce message a déjà été rapporté.',
 	'ALREADY_REPORTED_PM'	=> 'Ce message privé a déjà été rapporté.',
 	'ALREADY_WARNED'		=> 'Un avertissement a déjà été prononcé pour ce message.',
 	'APPROVE'				=> 'Approuver',
 	'APPROVE_POST'			=> 'Approuver le message',
-	'APPROVE_POST_CONFIRM'	=> 'Êtes-vous sûr de vouloir approuver ce message ?',
+	'APPROVE_POST_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir approuver ce message ?',
 	'APPROVE_POSTS'			=> 'Approuver les messages',
-	'APPROVE_POSTS_CONFIRM'	=> 'Êtes-vous sûr de vouloir approuver les messages sélectionnés ?',
+	'APPROVE_POSTS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir approuver les messages sélectionnés ?',
 
 	'CANNOT_MOVE_SAME_FORUM'=> 'Vous ne pouvez pas déplacer ce sujet dans ce forum car il y est déjà présent.',
 	'CANNOT_WARN_ANONYMOUS'	=> 'Vous ne pouvez pas distribuer d’avertissements aux visiteurs.',
@@ -62,36 +60,36 @@ $lang = array_merge($lang, array(
 	'CAN_LEAVE_BLANK'		=> 'Ceci peut être laissé vide.',
 	'CHANGE_POSTER'			=> 'Modifier l’auteur ',
 	'CLOSE_PM_REPORT'		=> 'Fermer le rapport de MP',
-	'CLOSE_PM_REPORT_CONFIRM'	=> 'Êtes-vous sûr de vouloir fermer le rapport de MP que vous avez sélectionné ?',
+	'CLOSE_PM_REPORT_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir fermer le rapport de MP que vous avez sélectionné ?',
 	'CLOSE_PM_REPORTS'		=> 'Fermer les rapports de MP',
-	'CLOSE_PM_REPORTS_CONFIRM'	=> 'Êtes-vous sûr de vouloir fermer les rapports de MP que vous avez sélectionnés ?',
+	'CLOSE_PM_REPORTS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir fermer les rapports de MP que vous avez sélectionnés ?',
 	'CLOSE_REPORT'			=> 'Fermer le rapport',
-	'CLOSE_REPORT_CONFIRM'	=> 'Êtes-vous sûr de vouloir fermer le rapport que vous avez sélectionné ?',
+	'CLOSE_REPORT_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir fermer le rapport que vous avez sélectionné ?',
 	'CLOSE_REPORTS'			=> 'Fermer les rapports',
-	'CLOSE_REPORTS_CONFIRM'	=> 'Êtes-vous sûr de vouloir fermer les rapports que vous avez sélectionnés ?',
+	'CLOSE_REPORTS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir fermer les rapports que vous avez sélectionnés ?',
 
 	'DELETE_PM_REPORT'			=> 'Supprimer le rapport de MP',
-	'DELETE_PM_REPORT_CONFIRM'	=> 'Êtes-vous sûr de vouloir supprimer le rapport de MP que vous avez sélectionné ?',
+	'DELETE_PM_REPORT_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir supprimer le rapport de MP que vous avez sélectionné ?',
 	'DELETE_PM_REPORTS'			=> 'Supprimer les rapports de MP',
-	'DELETE_PM_REPORTS_CONFIRM'	=> 'Êtes-vous sûr de vouloir supprimer les rapports de MP que vous avez sélectionnés ?',
+	'DELETE_PM_REPORTS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir supprimer les rapports de MP que vous avez sélectionnés ?',
 	'DELETE_POSTS'				=> 'Supprimer les messages',
-	'DELETE_POSTS_CONFIRM'		=> 'Êtes-vous sûr de vouloir supprimer ces messages ?',
-	'DELETE_POST_CONFIRM'		=> 'Êtes-vous sûr de vouloir supprimer ce message ?',
+	'DELETE_POSTS_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir supprimer ces messages ?',
+	'DELETE_POST_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir supprimer ce message ?',
 	'DELETE_REPORT'				=> 'Supprimer le rapport',
-	'DELETE_REPORT_CONFIRM'		=> 'Êtes-vous sûr de vouloir supprimer le rapport que vous avez sélectionné ?',
+	'DELETE_REPORT_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir supprimer le rapport que vous avez sélectionné ?',
 	'DELETE_REPORTS'			=> 'Supprimer les rapports',
-	'DELETE_REPORTS_CONFIRM'	=> 'Êtes-vous sûr de vouloir supprimer les rapports que vous avez sélectionnés ?',
+	'DELETE_REPORTS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir supprimer les rapports que vous avez sélectionnés ?',
 	'DELETE_SHADOW_TOPIC'		=> 'Supprimer la redirection du sujet',
 	'DELETE_TOPICS'				=> 'Supprimer les sujets sélectionnés',
-	'DELETE_TOPICS_CONFIRM'		=> 'Êtes-vous sûr de vouloir supprimer ces sujets ?',
-	'DELETE_TOPIC_CONFIRM'		=> 'Êtes-vous sûr de vouloir supprimer ce sujet ?',
+	'DELETE_TOPICS_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir supprimer ces sujets ?',
+	'DELETE_TOPIC_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir supprimer ce sujet ?',
 	'DISAPPROVE'				=> 'Désapprouver',
 	'DISAPPROVE_REASON'			=> 'Raison de la désapprobation ',
 	'DISAPPROVE_POST'			=> 'Désapprouver le message',
-	'DISAPPROVE_POST_CONFIRM'	=> 'Êtes-vous sûr de vouloir désapprouver ce message ?',
+	'DISAPPROVE_POST_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir désapprouver ce message ?',
 	'DISAPPROVE_POSTS'			=> 'Désapprouver les messages',
-	'DISAPPROVE_POSTS_CONFIRM'	=> 'Êtes-vous sûr de vouloir désapprouver les messages que vous avez sélectionnés ?',
-	'DISPLAY_LOG'				=> 'Afficher les entrées précédentes ',
+	'DISAPPROVE_POSTS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir désapprouver les messages que vous avez sélectionnés ?',
+	'DISPLAY_LOG'				=> 'Afficher les éléments précédents ',
 	'DISPLAY_OPTIONS'			=> 'Options d’affichage',
 
 	'EMPTY_REPORT'					=> 'Vous devez saisir une description lorsque vous sélectionnez cette raison.',
@@ -100,9 +98,9 @@ $lang = array_merge($lang, array(
 	'FEEDBACK'				=> 'Remarque',
 	'FORK'					=> 'Copier',
 	'FORK_TOPIC'			=> 'Copier le sujet',
-	'FORK_TOPIC_CONFIRM'	=> 'Êtes-vous sûr de vouloir copier ce sujet ?',
+	'FORK_TOPIC_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir copier ce sujet ?',
 	'FORK_TOPICS'			=> 'Copier les sujets sélectionnés',
-	'FORK_TOPICS_CONFIRM'	=> 'Êtes-vous sûr de vouloir copier les sujets que vous avez sélectionnés ?',
+	'FORK_TOPICS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir copier les sujets que vous avez sélectionnés ?',
 	'FORUM_DESC'			=> 'Description',
 	'FORUM_NAME'			=> 'Nom du forum',
 	'FORUM_NOT_EXIST'		=> 'Le forum auquel vous souhaitez accéder n’existe pas.',
@@ -126,13 +124,13 @@ $lang = array_merge($lang, array(
 	'LIST_REPORTS'				=> '%d rapports',
 	'LOCK'						=> 'Verrouiller',
 	'LOCK_POST_POST'			=> 'Verrouiller le message',
-	'LOCK_POST_POST_CONFIRM'	=> 'Êtes-vous sûr de vouloir empêcher l’édition de ce message ?',
+	'LOCK_POST_POST_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir empêcher l’édition de ce message ?',
 	'LOCK_POST_POSTS'			=> 'Verrouiller les messages sélectionnés',
-	'LOCK_POST_POSTS_CONFIRM'	=> 'Êtes-vous sûr de vouloir empêcher l’édition des messages que vous avez sélectionnés ?',
-	'LOCK_TOPIC_CONFIRM'		=> 'Êtes-vous sûr de vouloir verrouiller ce sujet ?',
+	'LOCK_POST_POSTS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir empêcher l’édition des messages que vous avez sélectionnés ?',
+	'LOCK_TOPIC_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir verrouiller ce sujet ?',
 	'LOCK_TOPICS'				=> 'Verrouiller les sujets sélectionnés',
-	'LOCK_TOPICS_CONFIRM'		=> 'Êtes-vous sûr de vouloir verrouiller tous les sujets que vous avez sélectionnés ?',
-	'LOGS_CURRENT_TOPIC'		=> 'Consulte actuellement les historiques de :',
+	'LOCK_TOPICS_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir verrouiller tous les sujets que vous avez sélectionnés ?',
+	'LOGS_CURRENT_TOPIC'		=> 'Consulte actuellement l’historique de :',
 	'LOGIN_EXPLAIN_MCP'			=> 'Vous devez vous connecter afin de modérer ce forum.',
 	'LOGVIEW_VIEWTOPIC'			=> 'Consulter le sujet',
 	'LOGVIEW_VIEWLOGS'			=> 'Consulter l’historique du sujet',
@@ -140,7 +138,7 @@ $lang = array_merge($lang, array(
 	'LOOKUP_ALL'				=> 'Rechercher toutes les adresses IP',
 	'LOOKUP_IP'					=> 'Rechercher une adresse IP',
 
-	'MARKED_NOTES_DELETED'		=> 'Toutes les notes sur l’utilisateur ont été supprimées avec succès.',
+	'MARKED_NOTES_DELETED'		=> 'Toutes les notes sur l’utilisateur ont été supprimées.',
 
 	'MCP_ADD'						=> 'Ajouter un avertissement',
 
@@ -149,10 +147,10 @@ $lang = array_merge($lang, array(
 	'MCP_BAN_IPS'				=> 'Bannir des adresses IP',
 	'MCP_BAN_USERNAMES'			=> 'Bannir des noms d’utilisateurs',
 
-	'MCP_LOGS'						=> 'Historique(s) des modérateurs',
+	'MCP_LOGS'						=> 'Historique des modérateurs',
 	'MCP_LOGS_FRONT'				=> 'Page principale',
-	'MCP_LOGS_FORUM_VIEW'			=> 'Historique(s) des forums',
-	'MCP_LOGS_TOPIC_VIEW'			=> 'Historique(s) des sujets',
+	'MCP_LOGS_FORUM_VIEW'			=> 'Historique des forums',
+	'MCP_LOGS_TOPIC_VIEW'			=> 'Historique des sujets',
 
 	'MCP_MAIN'						=> 'Principal',
 	'MCP_MAIN_FORUM_VIEW'			=> 'Consulter le forum',
@@ -160,21 +158,21 @@ $lang = array_merge($lang, array(
 	'MCP_MAIN_POST_DETAILS'			=> 'Informations sur le message',
 	'MCP_MAIN_TOPIC_VIEW'			=> 'Consulter le sujet',
 	'MCP_MAKE_ANNOUNCEMENT'			=> 'Modifier en « annonce »',
-	'MCP_MAKE_ANNOUNCEMENT_CONFIRM'	=> 'Êtes-vous sûr de vouloir modifier ce sujet en « annonce » ?',
+	'MCP_MAKE_ANNOUNCEMENT_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir modifier ce sujet en « annonce » ?',
 	'MCP_MAKE_ANNOUNCEMENTS'		=> 'Modifier en « annonces »',
-	'MCP_MAKE_ANNOUNCEMENTS_CONFIRM'=> 'Êtes-vous sûr de vouloir modifier les sujets que vous avez sélectionnés en « annonces » ?',
+	'MCP_MAKE_ANNOUNCEMENTS_CONFIRM'=> 'Êtes-vous sûr(e) de vouloir modifier les sujets que vous avez sélectionnés en « annonces » ?',
 	'MCP_MAKE_GLOBAL'				=> 'Modifier en « annonce globale »',
-	'MCP_MAKE_GLOBAL_CONFIRM'		=> 'Êtes-vous sûr de vouloir modifier ce sujet en « annonce globale » ?',
+	'MCP_MAKE_GLOBAL_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir modifier ce sujet en « annonce globale » ?',
 	'MCP_MAKE_GLOBALS'				=> 'Modifier en « annonces globales »',
-	'MCP_MAKE_GLOBALS_CONFIRM'		=> 'Êtes-vous sûr de vouloir modifier les sujets que vous avez sélectionnés en « annonces globales » ?',
+	'MCP_MAKE_GLOBALS_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir modifier les sujets que vous avez sélectionnés en « annonces globales » ?',
 	'MCP_MAKE_STICKY'				=> 'Modifier en « note »',
-	'MCP_MAKE_STICKY_CONFIRM'		=> 'Êtes-vous sûr de vouloir modifier ce sujet en « note » ?',
+	'MCP_MAKE_STICKY_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir modifier ce sujet en « note » ?',
 	'MCP_MAKE_STICKIES'				=> 'Modifier en « notes »',
-	'MCP_MAKE_STICKIES_CONFIRM'		=> 'Êtes-vous sûr de vouloir modifier les sujets que vous avez sélectionnés en « notes » ?',
+	'MCP_MAKE_STICKIES_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir modifier les sujets que vous avez sélectionnés en « notes » ?',
 	'MCP_MAKE_NORMAL'				=> 'Modifier en « sujet standard »',
-	'MCP_MAKE_NORMAL_CONFIRM'		=> 'Êtes-vous sûr de vouloir modifier ce sujet en « sujet standard » ?',
+	'MCP_MAKE_NORMAL_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir modifier ce sujet en « sujet standard » ?',
 	'MCP_MAKE_NORMALS'				=> 'Modifier en « sujets standards »',
-	'MCP_MAKE_NORMALS_CONFIRM'		=> 'Êtes-vous sûr de vouloir modifier les sujets que vous avez sélectionnés en « sujets standards » ?',
+	'MCP_MAKE_NORMALS_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir modifier les sujets que vous avez sélectionnés en « sujets standards » ?',
 
 	'MCP_NOTES'						=> 'Note(s) sur l’utilisateur',
 	'MCP_NOTES_FRONT'				=> 'Page principale',
@@ -208,27 +206,27 @@ $lang = array_merge($lang, array(
 	'MCP_WARN'				=> 'Avertissement(s)',
 	'MCP_WARN_FRONT'		=> 'Page principale',
 	'MCP_WARN_LIST'			=> 'Liste des avertissements',
-	'MCP_WARN_POST'			=> 'Avertir pour le message spécifique',
+	'MCP_WARN_POST'			=> 'Avertir concernant le message spécifique',
 	'MCP_WARN_USER'			=> 'Avertir l’utilisateur',
 
-	'MERGE_POSTS_CONFIRM'	=> 'Êtes-vous sûr de vouloir déplacer les messages que vous avez sélectionnés ?',
+	'MERGE_POSTS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir déplacer les messages que vous avez sélectionnés ?',
 	'MERGE_TOPIC_EXPLAIN'	=> 'En utilisant le formulaire ci-dessous, vous pouvez déplacer les messages que vous avez sélectionnés dans un autre sujet. Les messages seront retirés de ce sujet afin d’être fusionnés dans un autre sujet. Ces messages ne seront pas réordonnés et apparaîtront comme si les utilisateurs les avaient publiés dans le nouveau sujet.<br />Veuillez saisir le numéro d’identification du sujet de destination ou cliquer sur « Sélectionner le sujet » afin d’en rechercher un.',
 	'MERGE_TOPIC_ID'		=> 'Numéro d’identification du sujet de destination ',
 	'MERGE_TOPICS'			=> 'Fusionner les sujets',
-	'MERGE_TOPICS_CONFIRM'	=> 'Êtes-vous sûr de vouloir fusionner les sujets que vous avez sélectionnés ?',
+	'MERGE_TOPICS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir fusionner les sujets que vous avez sélectionnés ?',
 	'MODERATE_FORUM'		=> 'Modérer le forum ',
 	'MODERATE_TOPIC'		=> 'Modérer le sujet',
 	'MODERATE_POST'			=> 'Modérer le message',
 	'MOD_OPTIONS'			=> 'Options du modérateur ',
 	'MORE_INFO'				=> 'Informations supplémentaires',
 	'MOST_WARNINGS'			=> 'Les utilisateurs ayant le plus grand nombre d’avertissements',
-	'MOVE_TOPIC_CONFIRM'	=> 'Êtes-vous sûr de vouloir déplacer le sujet vers un nouveau forum ?',
+	'MOVE_TOPIC_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir déplacer le sujet vers un nouveau forum ?',
 	'MOVE_TOPICS'			=> 'Déplacer les sujets sélectionnés',
-	'MOVE_TOPICS_CONFIRM'	=> 'Êtes-vous sûr de vouloir déplacer les sujets que vous avez sélectionnés vers un nouveau forum ?',
+	'MOVE_TOPICS_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir déplacer les sujets que vous avez sélectionnés vers un nouveau forum ?',
 
-	'NOTIFY_POSTER_APPROVAL'		=> 'Avertir l’auteur du message à propos de l’approbation ?',
-	'NOTIFY_POSTER_DISAPPROVAL'		=> 'Avertir l’auteur du message à propos de la désapprobation ?',
-	'NOTIFY_USER_WARN'				=> 'Avertir l’utilisateur à propos de l’avertissement ?',
+	'NOTIFY_POSTER_APPROVAL'		=> 'Envoyer une notification à l’auteur du message concernant l’approbation ?',
+	'NOTIFY_POSTER_DISAPPROVAL'		=> 'Envoyer une notification à l’auteur du message concernant la désapprobation ?',
+	'NOTIFY_USER_WARN'				=> 'Envoyer une notification à l’utilisateur concernant l’avertissement ?',
 	'NOT_MODERATOR'					=> 'Vous n’êtes pas un modérateur de ce forum.',
 	'NO_DESTINATION_FORUM'			=> 'Veuillez sélectionner un forum de destination.',
 	'NO_DESTINATION_FORUM_FOUND'	=> 'Aucun forum de destination n’est disponible.',
@@ -250,31 +248,31 @@ $lang = array_merge($lang, array(
 	'ONLY_TOPIC'			=> 'Uniquement le sujet « %s »',
 	'OTHER_USERS'			=> 'Autres utilisateurs ayant publiés avec cette adresse IP',
 
-	'PM_REPORT_CLOSED_SUCCESS'	=> 'Le rapport de MP que vous avez sélectionné a été fermé avec succès.',
-	'PM_REPORT_DELETED_SUCCESS'	=> 'Le rapport de MP que vous avez sélectionné a été supprimé avec succès.',
-	'PM_REPORTED_SUCCESS'		=> 'Ce message privé a été rapporté avec succès.',
+	'PM_REPORT_CLOSED_SUCCESS'	=> 'Le rapport de MP que vous avez sélectionné a été fermé.',
+	'PM_REPORT_DELETED_SUCCESS'	=> 'Le rapport de MP que vous avez sélectionné a été supprimé.',
+	'PM_REPORTED_SUCCESS'		=> 'Ce message privé a été rapporté.',
 	'PM_REPORT_TOTAL'			=> 'Au total, il y a <strong>1</strong> rapport de MP à traiter.',
-	'PM_REPORTS_CLOSED_SUCCESS'	=> 'Les rapports de MP que vous avez sélectionnés ont été fermés avec succès.',
-	'PM_REPORTS_DELETED_SUCCESS'=> 'Les rapport de MP que vous avez sélectionnés ont été supprimés avec succès.',
+	'PM_REPORTS_CLOSED_SUCCESS'	=> 'Les rapports de MP que vous avez sélectionnés ont été fermés.',
+	'PM_REPORTS_DELETED_SUCCESS'=> 'Les rapport de MP que vous avez sélectionnés ont été supprimés.',
 	'PM_REPORTS_TOTAL'			=> 'Au total, il y a <strong>%d</strong> rapports de MP à traiter.',
 	'PM_REPORTS_ZERO_TOTAL'		=> 'Il n’y a aucun rapport de MP à traiter.',
 	'PM_REPORT_DETAILS'			=> 'Informations sur le rapport de message privé',
 	'POSTER'					=> 'Auteur',
-	'POSTS_APPROVED_SUCCESS'	=> 'Les messages que vous avez sélectionnés ont été approuvés avec succès.',
-	'POSTS_DELETED_SUCCESS'		=> 'Les messages que vous avez sélectionnés ont été supprimés de la base de données avec succès.',
-	'POSTS_DISAPPROVED_SUCCESS'	=> 'Les messages que vous avez sélectionnés ont été désapprouvés avec succès.',
-	'POSTS_LOCKED_SUCCESS'		=> 'Les messages que vous avez sélectionnés ont été verrouillés avec succès.',
-	'POSTS_MERGED_SUCCESS'		=> 'Les messages que vous avez sélectionnés ont été fusionnés avec succès.',
-	'POSTS_UNLOCKED_SUCCESS'	=> 'Les messages que vous avez sélectionnés ont été déverrouillés avec succès.',
+	'POSTS_APPROVED_SUCCESS'	=> 'Les messages que vous avez sélectionnés ont été approuvés.',
+	'POSTS_DELETED_SUCCESS'		=> 'Les messages que vous avez sélectionnés ont été supprimés de la base de données.',
+	'POSTS_DISAPPROVED_SUCCESS'	=> 'Les messages que vous avez sélectionnés ont été désapprouvés.',
+	'POSTS_LOCKED_SUCCESS'		=> 'Les messages que vous avez sélectionnés ont été verrouillés.',
+	'POSTS_MERGED_SUCCESS'		=> 'Les messages que vous avez sélectionnés ont été fusionnés.',
+	'POSTS_UNLOCKED_SUCCESS'	=> 'Les messages que vous avez sélectionnés ont été déverrouillés.',
 	'POSTS_PER_PAGE'			=> 'Messages par page ',
 	'POSTS_PER_PAGE_EXPLAIN'	=> 'Réglez cette valeur sur 0 afin de consulter tous les messages.',
-	'POST_APPROVED_SUCCESS'		=> 'Le message que vous avez sélectionné a été approuvé avec succès.',
-	'POST_DELETED_SUCCESS'		=> 'Le message que vous avez sélectionné a été supprimé de la base de données avec succès.',
-	'POST_DISAPPROVED_SUCCESS'	=> 'Le message que vous avez sélectionné a été désapprouvé avec succès.',
-	'POST_LOCKED_SUCCESS'		=> 'Le message a été verrouillé avec succès.',
+	'POST_APPROVED_SUCCESS'		=> 'Le message que vous avez sélectionné a été approuvé.',
+	'POST_DELETED_SUCCESS'		=> 'Le message que vous avez sélectionné a été supprimé de la base de données.',
+	'POST_DISAPPROVED_SUCCESS'	=> 'Le message que vous avez sélectionné a été désapprouvé.',
+	'POST_LOCKED_SUCCESS'		=> 'Le message a été verrouillé.',
 	'POST_NOT_EXIST'			=> 'Le message que vous souhaitez consulter n’existe pas.',
-	'POST_REPORTED_SUCCESS'		=> 'Ce message a été rapporté avec succès.',
-	'POST_UNLOCKED_SUCCESS'		=> 'Le message a été déverrouillé avec succès.',
+	'POST_REPORTED_SUCCESS'		=> 'Ce message a été rapporté.',
+	'POST_UNLOCKED_SUCCESS'		=> 'Le message a été déverrouillé.',
 
 	'READ_USERNOTES'			=> 'Note(s) sur l’utilisateur',
 	'READ_WARNINGS'				=> 'Avertissements de l’utilisateur',
@@ -282,19 +280,19 @@ $lang = array_merge($lang, array(
 	'REPORTED'					=> 'Rapporté',
 	'REPORTED_BY'				=> 'Rapporté par',
 	'REPORTED_ON_DATE'			=> 'le',
-	'REPORTS_CLOSED_SUCCESS'	=> 'Les rapports que vous avez sélectionnés ont été fermés avec succès.',
-	'REPORTS_DELETED_SUCCESS'	=> 'Les rapports que vous avez sélectionnés ont été supprimés avec succès.',
+	'REPORTS_CLOSED_SUCCESS'	=> 'Les rapports que vous avez sélectionnés ont été fermés.',
+	'REPORTS_DELETED_SUCCESS'	=> 'Les rapports que vous avez sélectionnés ont été supprimés.',
 	'REPORTS_TOTAL'				=> 'Au total, il y a <strong>%d</strong> rapports à traiter.',
 	'REPORTS_ZERO_TOTAL'		=> 'Il n’y a aucun rapport à traiter.',
 	'REPORT_CLOSED'				=> 'Ce rapport a déjà été fermé.',
-	'REPORT_CLOSED_SUCCESS'		=> 'Le rapport que vous avez sélectionné a été fermé avec succès.',
-	'REPORT_DELETED_SUCCESS'	=> 'Le rapport que vous avez sélectionné a été supprimé avec succès.',
+	'REPORT_CLOSED_SUCCESS'		=> 'Le rapport que vous avez sélectionné a été fermé.',
+	'REPORT_DELETED_SUCCESS'	=> 'Le rapport que vous avez sélectionné a été supprimé.',
 	'REPORT_DETAILS'			=> 'Informations sur le rapport',
 	'REPORT_MESSAGE'			=> 'Rapporter ce message',
-	'REPORT_MESSAGE_EXPLAIN'	=> 'Utilisez ce formulaire afin de rapporter le message privé que vous avez sélectionné. Seuls les messages violant des règles du forum devraient être rapportés. <strong>Lorsqu’un message privé est rapporté, son contenu est rendu visible à tous les modérateurs.</strong>',
-	'REPORT_NOTIFY'				=> 'M’avertir',
-	'REPORT_NOTIFY_EXPLAIN'		=> 'Vous avertir lorsque votre rapport sera traité.',
-	'REPORT_POST_EXPLAIN'		=> 'Utilisez ce formulaire afin de rapporter le message que vous avez sélectionné aux modérateurs et aux administrateurs du forum. Seuls les messages violant des règles du forum devraient être rapportés.',
+	'REPORT_MESSAGE_EXPLAIN'	=> 'Utilisez ce formulaire afin de rapporter le message privé que vous avez sélectionné. Seuls les messages ne respectant pas les règles du forum devraient être rapportés. <strong>Lorsqu’un message privé est rapporté, son contenu est rendu visible à tous les modérateurs.</strong>',
+	'REPORT_NOTIFY'				=> 'M’envoyer une notification',
+	'REPORT_NOTIFY_EXPLAIN'		=> 'Vous enverra une notification lorsque votre rapport sera traité.',
+	'REPORT_POST_EXPLAIN'		=> 'Utilisez ce formulaire afin de rapporter le message que vous avez sélectionné aux modérateurs et aux administrateurs du forum. Seuls les messages ne respectant pas les règles du forum devraient être rapportés.',
 	'REPORT_REASON'				=> 'Raison du rapport',
 	'REPORT_TIME'				=> 'Date du rapport',
 	'REPORT_TOTAL'				=> 'Au total, il y a <strong>1</strong> rapport à traiter.',
@@ -311,7 +309,7 @@ $lang = array_merge($lang, array(
 	'SEARCH_POSTS_BY_USER'				=> 'Rechercher les messages par',
 	'SELECT_ACTION'						=> 'Sélectionner une action souhaitée',
 	'SELECT_FORUM_GLOBAL_ANNOUNCEMENT'	=> 'Veuillez sélectionner le forum dans lequel vous souhaitez afficher cette annonce globale.',
-	'SELECT_FORUM_GLOBAL_ANNOUNCEMENTS'	=> 'Un ou plusieurs sujets que vous avez sélectionné(s) sont des annonces globales. Veuillez sélectionner le forum dans lequel vous souhaitez qu’elles soient affichées.',
+	'SELECT_FORUM_GLOBAL_ANNOUNCEMENTS'	=> 'Un ou plusieurs sujets que vous avez sélectionné sont des annonces globales. Veuillez sélectionner le forum dans lequel vous souhaitez qu’elles soient affichées.',
 	'SELECT_MERGE'						=> 'Sélectionner pour la fusion',
 	'SELECT_TOPICS_FROM'				=> 'Sélectionner les sujets de',
 	'SELECT_TOPIC'						=> 'Sélectionner le sujet',
@@ -325,34 +323,34 @@ $lang = array_merge($lang, array(
 	'SPLIT_POSTS'						=> 'Diviser les messages sélectionnés',
 	'SPLIT_SUBJECT'						=> 'Titre du nouveau sujet ',
 	'SPLIT_TOPIC_ALL'					=> 'Diviser le sujet à partir des messages sélectionnés',
-	'SPLIT_TOPIC_ALL_CONFIRM'			=> 'Êtes-vous sûr de vouloir diviser ce sujet ?',
+	'SPLIT_TOPIC_ALL_CONFIRM'			=> 'Êtes-vous sûr(e) de vouloir diviser ce sujet ?',
 	'SPLIT_TOPIC_BEYOND'				=> 'Diviser le sujet à partir du message sélectionné',
-	'SPLIT_TOPIC_BEYOND_CONFIRM'		=> 'Êtes-vous sûr de vouloir diviser ce sujet à partir du message que vous avez sélectionné ?',
+	'SPLIT_TOPIC_BEYOND_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir diviser ce sujet à partir du message que vous avez sélectionné ?',
 	'SPLIT_TOPIC_EXPLAIN'				=> 'En utilisant le formulaire ci-dessous, vous pouvez diviser un sujet en deux. Pour ce faire, sélectionnez de manière individuelle les sujets ou divisez le sujet à partir d’un message que vous avez sélectionné.',
 
 	'THIS_PM_IP'				=> 'IP de ce message privé ',
 	'THIS_POST_IP'				=> 'IP de ce message ',
-	'TOPICS_APPROVED_SUCCESS'	=> 'Les sujets que vous avez sélectionnés ont été approuvés avec succès.',
-	'TOPICS_DELETED_SUCCESS'	=> 'Les sujets que vous avez sélectionnés ont été supprimés de la base de données avec succès.',
-	'TOPICS_DISAPPROVED_SUCCESS'=> 'Les sujets que vous avez sélectionnés ont été désapprouvés avec succès.',
-	'TOPICS_FORKED_SUCCESS'		=> 'Les sujets que vous avez sélectionnés ont été copiés avec succès.',
-	'TOPICS_LOCKED_SUCCESS'		=> 'Les sujets que vous avez sélectionnés ont été verrouillés avec succès.',
-	'TOPICS_MOVED_SUCCESS'		=> 'Les sujets que vous avez sélectionnés ont été déplacés avec succès.',
-	'TOPICS_RESYNC_SUCCESS'		=> 'Les sujets que vous avez sélectionnés ont été resynchronisés avec succès.',
-	'TOPICS_TYPE_CHANGED'		=> 'Les types de sujet ont été modifiés avec succès.',
-	'TOPICS_UNLOCKED_SUCCESS'	=> 'Les sujets que vous avez sélectionnés ont été déverrouillés avec succès.',
-	'TOPIC_APPROVED_SUCCESS'	=> 'Le sujet que vous avez sélectionné a été approuvé avec succès.',
-	'TOPIC_DELETED_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été supprimé de la base de données avec succès.',
-	'TOPIC_DISAPPROVED_SUCCESS'	=> 'Le sujet que vous avez sélectionné a été désapprouvé avec succès.',
-	'TOPIC_FORKED_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été copié avec succès.',
-	'TOPIC_LOCKED_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été verrouillé avec succès.',
-	'TOPIC_MOVED_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été déplacé avec succès.',
+	'TOPICS_APPROVED_SUCCESS'	=> 'Les sujets que vous avez sélectionnés ont été approuvés.',
+	'TOPICS_DELETED_SUCCESS'	=> 'Les sujets que vous avez sélectionnés ont été supprimés de la base de données.',
+	'TOPICS_DISAPPROVED_SUCCESS'=> 'Les sujets que vous avez sélectionnés ont été désapprouvés.',
+	'TOPICS_FORKED_SUCCESS'		=> 'Les sujets que vous avez sélectionnés ont été copiés.',
+	'TOPICS_LOCKED_SUCCESS'		=> 'Les sujets que vous avez sélectionnés ont été verrouillés.',
+	'TOPICS_MOVED_SUCCESS'		=> 'Les sujets que vous avez sélectionnés ont été déplacés.',
+	'TOPICS_RESYNC_SUCCESS'		=> 'Les sujets que vous avez sélectionnés ont été resynchronisés.',
+	'TOPICS_TYPE_CHANGED'		=> 'Les types de sujet ont été modifiés.',
+	'TOPICS_UNLOCKED_SUCCESS'	=> 'Les sujets que vous avez sélectionnés ont été déverrouillés.',
+	'TOPIC_APPROVED_SUCCESS'	=> 'Le sujet que vous avez sélectionné a été approuvé.',
+	'TOPIC_DELETED_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été supprimé de la base de données.',
+	'TOPIC_DISAPPROVED_SUCCESS'	=> 'Le sujet que vous avez sélectionné a été désapprouvé.',
+	'TOPIC_FORKED_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été copié.',
+	'TOPIC_LOCKED_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été verrouillé.',
+	'TOPIC_MOVED_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été déplacé.',
 	'TOPIC_NOT_EXIST'			=> 'Le sujet que vous souhaitez consulter n’existe pas.',
-	'TOPIC_RESYNC_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été resynchronisé avec succès.',
-	'TOPIC_SPLIT_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été divisé avec succès.',
+	'TOPIC_RESYNC_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été resynchronisé.',
+	'TOPIC_SPLIT_SUCCESS'		=> 'Le sujet que vous avez sélectionné a été divisé.',
 	'TOPIC_TIME'				=> 'Heure du sujet',
-	'TOPIC_TYPE_CHANGED'		=> 'Le type de sujet a été modifié avec succès.',
-	'TOPIC_UNLOCKED_SUCCESS'	=> 'Le sujet que vous avez sélectionné a été déverrouillé avec succès.',
+	'TOPIC_TYPE_CHANGED'		=> 'Le type de sujet a été modifié.',
+	'TOPIC_UNLOCKED_SUCCESS'	=> 'Le sujet que vous avez sélectionné a été déverrouillé.',
 	'TOTAL_WARNINGS'			=> 'Nombre total d’avertissements',
 
 	'UNAPPROVED_POSTS_TOTAL'		=> 'Au total, il y a <strong>%d</strong> messages en attente d’approbation.',
@@ -362,17 +360,17 @@ $lang = array_merge($lang, array(
 	'UNLOCK_POST'					=> 'Déverrouiller le message',
 	'UNLOCK_POST_EXPLAIN'			=> 'Autoriser l’édition',
 	'UNLOCK_POST_POST'				=> 'Déverrouiller le message',
-	'UNLOCK_POST_POST_CONFIRM'		=> 'Êtes-vous sûr de vouloir autoriser l’édition de ce message ?',
+	'UNLOCK_POST_POST_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir autoriser l’édition de ce message ?',
 	'UNLOCK_POST_POSTS'				=> 'Déverrouiller les messages sélectionnés',
-	'UNLOCK_POST_POSTS_CONFIRM'		=> 'Êtes-vous sûr de vouloir autoriser l’édition des messages que vous avez sélectionnés ?',
+	'UNLOCK_POST_POSTS_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir autoriser l’édition des messages que vous avez sélectionnés ?',
 	'UNLOCK_TOPIC'					=> 'Déverrouiller le sujet',
-	'UNLOCK_TOPIC_CONFIRM'			=> 'Êtes-vous sûr de vouloir déverrouiller ce sujet ?',
+	'UNLOCK_TOPIC_CONFIRM'			=> 'Êtes-vous sûr(e) de vouloir déverrouiller ce sujet ?',
 	'UNLOCK_TOPICS'					=> 'Déverrouiller les sujets sélectionnés',
-	'UNLOCK_TOPICS_CONFIRM'			=> 'Êtes-vous sûr de vouloir déverrouiller tous les sujets que vous avez sélectionnés ?',
+	'UNLOCK_TOPICS_CONFIRM'			=> 'Êtes-vous sûr(e) de vouloir déverrouiller tous les sujets que vous avez sélectionnés ?',
 	'USER_CANNOT_POST'				=> 'Vous ne pouvez pas publier de message dans ce forum.',
 	'USER_CANNOT_REPORT'			=> 'Vous ne pouvez pas rapporter les messages de ce forum.',
-	'USER_FEEDBACK_ADDED'			=> 'La remarque a été ajouté sur l’utilisateur avec succès.',
-	'USER_WARNING_ADDED'			=> 'L’utilisateur a été averti avec succès.',
+	'USER_FEEDBACK_ADDED'			=> 'La remarque a été ajoutée sur l’utilisateur.',
+	'USER_WARNING_ADDED'			=> 'L’utilisateur a été averti.',
 
 	'VIEW_DETAILS'			=> 'Consulter les informations',
 	'VIEW_PM'				=> 'Consulter le message privé',
@@ -390,7 +388,7 @@ $lang = array_merge($lang, array(
 	'report_reasons'		=> array(
 		'TITLE'	=> array(
 			'WAREZ'		=> 'Piratage',
-			'SPAM'		=> 'Pourriel',
+			'SPAM'		=> 'Spam',
 			'OFF_TOPIC'	=> 'Hors-sujet',
 			'OTHER'		=> 'Autre',
 		),
@@ -398,7 +396,7 @@ $lang = array_merge($lang, array(
 			'WAREZ'		=> 'Le message rapporté contient un ou plusieurs liens dirigeant vers des ressources illégales ou des logiciels piratés.',
 			'SPAM'		=> 'Le message rapporté contient de la publicité visant à promouvoir un site internet ou un produit.',
 			'OFF_TOPIC'	=> 'Le message rapporté est hors-sujet.',
-			'OTHER'		=> 'Le message rapporté ne correspond à aucune catégorie, veuillez utiliser le champ d’information supplémentaire.',
+			'OTHER'		=> 'Le message rapporté ne correspond à aucune catégorie, veuillez utiliser le champ d’information complémentaire.',
 		)
 	),
 ));
